*! version 1.0.5  21mar2006  by Marc Muendler muendler@ucsd.edu

cd "$rootslct"
clear
set matsize 400
set mem 400m
set more off

capture mkdir "$rootslct/tex/pop"
capture mkdir "$rootslct/tex/pop/pt$par-af$aff"  /* Directories not affected if they exist */

capture log close
log using "logs/reg-pop-pattern-ger-pt$par-af$aff.log", replace


/* REGIONAL PRESENCE PATTERNS IN POPULATION */
/*------------------------------------------*/

* external files
tempfile secfix isocntry naceconc iso3buba cntrgrpbem
global secfix "`secfix'"
use "$root/conc/sector-conc-nace", clear
sort buba_code
save `naceconc'
use "$root/conc/fdi-iso-country", clear
sort buba
compress
save `isocntry'
do "$dpref/#sector-definitions.do"
use "$root/conc/fdi-iso-country", clear
rename buba country
keep iso3code country 
sort country
compress
save `iso3buba'
use "$root/conc/cntry2bemgrp", clear
rename bubakey country
sort country
compress
save `cntrgrpbem'

local share $share

use "$root/Xdata/affils-outwfdi96-01-eur-03mar2006", clear
* rename bg share
keep firmid affil2id year share sec1 sec2_fix country cntrygrp
order firmid affil2id year share sec1 sec2_fix country cntrygrp
sort firmid affil2id year
count

* FROM #bemfiles.do
keep if year==2000 | year==1996
count

* FROM prep-parent-hostcntry-data-selct.do
keep if share>`share'
count
* country_grp definitions (as in swe-ger-conc.do)
foreach var in country {
    * tab `var'
    rename `var' bubakey  
    sort bubakey 
    merge bubakey using "$root/conc/cntry2bemgrp", nokeep
    count if _m~=3 & bubakey~=.
    if `r(N)' > 0 {
        disp as err "Incomplete country concordance"
        STOP
        }
    rename bubakey `var'
    rename cntrygrp_bem `var'grp_fix
    drop _merge
    }
rename countrygrp_fix cntrygrp_bem
label var cntrygrp_bem "Country group of affiliate"
sort firmid affil2id year
* sector and country resetting (similar to prep-summarize-affils.do)
do "$dpref/#sector-country-resetting.do"
* affiliate sector selection
if "$par" == "manf" {
  keep if sec1_aggbem>=2 & sec1_aggbem<=4
  }
if "$par" == "nonmf" {
  drop if sec1_aggbem>=2 & sec1_aggbem<=4
  }
if "$aff" == "manf" {
  keep if sec2_aggbem>=2 & sec2_aggbem<=4
  }
if "$aff" == "nonmf" {
  drop if sec2_aggbem>=2 & sec2_aggbem<=4
  }
count

* host country aggregation 
sort firmid affil2id year cntrybemgrp
bysort firmid: gen byte _sameaff = 1 if affil2id==affil2id[_n-1]
egen sameaff = sum(_sameaff), by(firmid year cntrybemgrp)
order firmid affil2id year cntrybemgrp sameaff _sameaff
collapse (count) numaffil=affil2id (max) sec1_bem sec1_aggbem sameaff, by (firmid country year cntrybemgrp) fast
sort firmid country year cntrybemgrp
bysort firmid: gen byte _samecty = 1 if country==country[_n-1]
egen samecty = sum(_samecty), by(firmid year cntrybemgrp)
drop _samecty
label var sec1_bem "Sector codes (BEM)"
label var sec1_aggbem "Sector codes (AGGBEM)"
label var numaffil "Count of affiliates"
label var sameaff "No. of same affiliates by region"
label var samecty "No. of same countries by region"

* FROM prep-translog-fdidata.do and prep-mvprobit-med-wagediff.do /* but retaining both years */
order firmid sec1_bem country year
sort country
merge country using `iso3buba', nokeep
tab _m
drop _m
sort country
merge country using `cntrgrpbem', nokeep
tab _m
drop _m
sort firmid year country
tempfile ptcntry
save `ptcntry'

* counts of same affil2id by mneid
preserve
  drop if year==1996
  keep firmid year cntrybemgrp sameaff samecty
  decode cntrybemgrp, gen(_cntrybemgrp)
  drop cntrybemgrp
  rename _cntrybemgrp cntrybemgrp
  replace cntrybemgrp = substr(cntrybemgrp,1,2)
  bysort firmid year cntrybemgrp: keep if _n==1
  rename firmid mneid
  reshape wide sameaff samecty, i(mneid year) j(cntrybemgrp) string
  sort mneid year
  tempfile sameaffcty
  save `sameaffcty'
restore


* FROM prep-translog-fdidata.do /* but retaining both years */
rename firmid firm
tempfile hom
preserve
     keep firm year sec1_bem
     gen byte cntrybemgrp = 0
     duplicates drop
     duplicates tag firm year, gen(_chk)
     count if _chk>=1
     if `r(N)' > 0 {
       disp as err "MNEs with contradictory home information"
       STOP
       }
     drop _chk
     compress
     sort firm year
     save `hom'
 restore
     keep firm year sec1_bem cntrybemgrp country numaffil
     duplicates drop
     compress
     sort firm year
append using `hom'
label define cntrybem 0 "HOM", modify
label var cntrybemgrp "Country group BEM"
qui do "$root/conc/secbem.do"
label values sec1_bem secbem
bysort firm cntrybemgrp year: egen reg_numcntry=count(country)
bysort firm cntrybemgrp year: egen reg_numaffil=sum(numaffil)
bysort firm cntrybemgrp year: keep if _n==1
keep firm year sec1_bem cntrybemgrp reg*
rename reg_numaffil naff
rename reg_numcntry ncty
keep firm year sec1_bem cntrybemgrp naff ncty
fillin firm year cntrybemgrp
bysort firm year: egen nobs=count(cntrybemgrp)
tab nobs
count if nobs~=5 & nobs~=.
    if `r(N)' > 0 {
        disp as err "wrong number of observations"
        STOP
        }
drop nobs
rename firm mneid
bysort mneid year: egen _sec = mean(sec1_bem)
replace sec1_bem = _sec if sec1_bem==.
tab _sec
drop _sec
bysort mneid year: egen nreg=sum(_fillin)
replace nreg=5-nreg
tab nreg
count
drop if nreg==. /* do NOT drop MNEs that have only data for one region */
rename _fillin nofdi
rename cntrybemgrp _cntrybemgrp
decode _cntrybemgrp, gen(cntrybemgrp)
drop _cntrybemgrp
compress
order mneid year cntrybemgrp
sort mneid year cntrybemgrp
order mneid year cntrybemgrp nreg
label var nreg "No. of active regions"
label var naff "No. of affiliates by region"
label var ncty "No. of countries by region"
label var nofdi "Indic.: No FDI"
tempfile translog
save `translog'

* FROM prep-mvprobit-med-wagediff.do /* but working on both years */
use `ptcntry'
keep firmid year country cntrybemgrp year sec1_bem
duplicates report firmid year country
count
collapse (max) sec1_bem, by(firmid year cntrybemgrp)  /* firmid year's and id's one-to-one */
duplicates report firmid year cntrybemgrp
count
fillin firmid year cntrybemgrp
count
gen byte chosen=(_fillin~=1)
label var sec1_bem "Sector codes (BEM)"
drop _fillin
* reshape and label for mvprobit
foreach name in sec1_bem {
  forvalues i=1996(4)2000 {
    local lblyr = substr("`i'",-2,2)
    local lbl : variable label `name'
    gen `name'_`i'= `name'
    replace `name'_`i'=. if year~=`i'
    bysort firmid: egen _help = max(`name'_`i')
    replace `name'_`i'=_help if `name'_`i'==.
    label var `name'_`i' "`lbl' `lblyr'"
    drop _help
    local lbl_reshp_2 : variable label `name'
    }
  drop `name'
  }
duplicates report firmid year cntrybemgrp
replace sec1_bem_1996=sec1_bem_2000 if sec1_bem_1996==. /* fill missing sectors */
replace sec1_bem_2000=sec1_bem_1996 if sec1_bem_2000==.
gen region_year= cntrybemgrp*100000+year
drop year cntrybemgrp
reshape wide chosen, i(firmid) j(region_year)
local i=0
foreach name in CEE DEV OIN WEU {
  local i=`i'+10
  forvalues j=1996(4)2000 {
    local lblyr = substr("`j'",-2,2)
    rename chosen`i'`j' chosen_`name'_`j'
    label var chosen_`name'_`j' "FDI presence `name' `lblyr'"
    }
  }
compress
rename firmid mneid
sort mneid
tempfile mvprobit
save `mvprobit'

* FROM translog-selct-2stp-cf.do /* but working on both years */
use `translog', clear
replace cntrybemgrp=(substr(cntrybemgrp,1,2))
reshape wide naff ncty nofdi, i(mneid year nreg) j(cntrybemgrp) string
sort mneid
merge mneid using `mvprobit'
tab _merge
drop _merge
sort mneid year
* regional presence indicators and parent level regressors
foreach reg in $regagg {
  foreach 4dyr in 1996 2000 {
    local yr = substr("`4dyr'",-2,2)
    local r2dg = substr("`reg'",1,2)
    rename chosen_`reg'_`4dyr' i`r2dg'`yr'
    }
  }
gen byte iHO96 = 1  /* Permanent presence in Home */
gen byte iHO00 = 1  /* Permanent presence in Home */
label var iHO96 "Presence HOM 96"
label var iHO00 "Presence HOM 00"

duplicates drop
sort mneid year
order mneid year nreg i*

tsset mneid year
sort mneid year
compress
save "$rootslct/Xdata/pop-reg-nonattrition-pt$par-af$aff", replace


/* FROM #reg-pattern-ger.do */
/*--------------------------*/

/* turnover and churning statistics */
/*-------------------------------*/

preserve
sort mneid year
keep mneid year naff*
reshape long naff, i(mneid year) j(reg) string
bysort mneid reg: gen chgaff = naff-naff[_n-1]
replace chgaff = 0 if chgaff==.
drop if year==1996
drop year naff
gen _expndaff = chgaff * (chgaff>0)
gen _cntrtaff = - chgaff * (chgaff<0)
egen expndaff = sum( _expndaff ), by(reg)
egen cntrtaff = sum( _cntrtaff ), by(reg)
drop _*
egen churnaff = sum(abs(chgaff)), by(reg)
replace churnaff = churnaff - abs(expndaff - cntrtaff)
keep reg churnaff
duplicates drop
sort reg
gen byte _ones = 1
encode reg, generate(_reg) label(reg)
tabl2tex churnaff, type(mean) r(_reg) c(_ones) p(tex/pop/pt$par-af$aff) name(churnaff) fancy replace digits(0)
mat drop churnaff_tbl
restore, preserve
sort mneid year
keep mneid year ncty*
reshape long ncty, i(mneid year) j(reg) string
bysort mneid reg: gen chgcty = ncty-ncty[_n-1]
replace chgcty = 0 if chgcty==.
drop if year==1996
drop year ncty
gen _expndcty = chgcty * (chgcty>0)
gen _cntrtcty = - chgcty * (chgcty<0)
egen expndcty = sum( _expndcty ), by(reg)
egen cntrtcty = sum( _cntrtcty ), by(reg)
drop _*
egen churncty = sum(abs(chgcty)), by(reg)
replace churncty = churncty - abs(expndcty - cntrtcty)
keep reg churncty
duplicates drop
sort reg
gen byte _ones = 1
encode reg, generate(_reg) label(reg)
tabl2tex churncty, type(mean) r(_reg) c(_ones) p(tex/pop/pt$par-af$aff) name(churncty) fancy replace digits(0)
mat drop churncty_tbl
restore


/* check overlap of pattern variables */
/*------------------------------------*/

egen byte _nregprbt96 = rsum(iCE96 iDE96 iOI96 iWE96 iHO96) if year==1996
egen byte _nregprbt00 = rsum(iCE00 iDE00 iOI00 iWE00 iHO00) if year==2000
egen byte nregprbt = rsum(_nregprbt96 _nregprbt00)
drop _nregprbt96 _nregprbt00
bysort year: summ nregprbt nreg
* note: there are differences between translog and probit presence patterns
*       translog may differ from probit presence information due to missing variables


/* pattern statistics */
/*--------------------*/

* transitions based on probit presence information (nregprbt)
gen byte _ind = (nregprbt==.)
replace nregprbt = 0 if _ind /* to check for missing in transition table */
xttrans nregprbt, freq
replace nregprbt = . if _ind
drop _ind

* transitions based on probit presence information (nregprbt), ignoring home presence
gen byte _ind = (nregprbt==1)
replace nregprbt = . if _ind /* to check for missing in transition table */
xttrans nregprbt, freq
replace nregprbt = 1 if _ind
drop _ind
tab nregprbt if year==1996
tab nregprbt if year==2000

* transitions based on translog presence information (nreg)
gen byte _ind = (nreg==.)
replace nreg = 0 if _ind /* to check for missing in transition table */
xttrans nreg, freq
replace nreg = . if _ind
drop _ind

* transitions based on translog presence information (nreg), ignoring missing
xttrans nreg, freq
tab nreg if year==1996
tab nreg if year==2000

* change in affiliate numbers
tsset mneid year
sort mneid year
foreach reg in $regagg {
  local r2dg = substr("`reg'",1,2)
  gen del_naff`r2dg' = naff`r2dg' - l.l.l.l.naff`r2dg'
  gen del_ncty`r2dg' = ncty`r2dg' - l.l.l.l.ncty`r2dg'
  replace naff`r2dg'=0 if naff`r2dg'==.
  replace ncty`r2dg'=0 if ncty`r2dg'==.
  }
foreach reg in $regagg {
  local r2dg = substr("`reg'",1,2)
  gen deluncdl_naff`r2dg' = naff`r2dg' - l.l.l.l.naff`r2dg'
  gen deluncdl_ncty`r2dg' = ncty`r2dg' - l.l.l.l.ncty`r2dg'
  replace naff`r2dg'=. if naff`r2dg'==0
  replace ncty`r2dg'=. if ncty`r2dg'==0
  }
summ2tex naff* del_naff*, c(mean sd N p50) name(summ_del_naff) p(tex/pop/pt$par-af$aff) replace detail
summ2tex naff* del_naff* if year==1996, c(mean sd N p50) name(summ_del_naff96) p(tex/pop/pt$par-af$aff) replace detail
summ2tex naff* del_naff* if year==2000, c(mean sd N p50) name(summ_del_naff00) p(tex/pop/pt$par-af$aff) replace detail
summ2tex ncty* del_ncty*, c(mean sd N p50) name(summ_del_ncty) p(tex/pop/pt$par-af$aff) replace detail
summ2tex ncty* del_ncty* if year==1996, c(mean sd N p50) name(summ_del_ncty96) p(tex/pop/pt$par-af$aff) replace detail
summ2tex ncty* del_ncty* if year==2000, c(mean sd N p50) name(summ_del_ncty00) p(tex/pop/pt$par-af$aff) replace detail
mat drop summ_del_naff_tbl summ_del_naff96_tbl summ_del_naff00_tbl summ_del_ncty_tbl summ_del_ncty96_tbl summ_del_ncty00_tbl

* changes in affiliate ids beyond change in affiliate numbers
sort mneid year
merge mneid year using `sameaffcty'
tab _m year
drop _m
foreach reg in $regagg {
  local r2dg = substr("`reg'",1,2)
  replace sameaff`r2dg'=0 if sameaff`r2dg'==. & year==2000
  replace samecty`r2dg'=0 if samecty`r2dg'==. & year==2000
  gen daff`r2dg' = naff`r2dg' - sameaff`r2dg'
  gen dcty`r2dg' = ncty`r2dg' - samecty`r2dg'
  gen reldaff`r2dg' = (naff`r2dg' - sameaff`r2dg')/naff`r2dg'
  gen reldcty`r2dg' = (ncty`r2dg' - samecty`r2dg')/ncty`r2dg'
  }
summ2tex daff* reldaff* deluncdl_naff* if year==2000, c(mean sd N p50) name(summ_daff00) p(tex/pop/pt$par-af$aff) replace detail
summ2tex dcty* reldcty* deluncdl_ncty* if year==2000, c(mean sd N p50) name(summ_dcty00) p(tex/pop/pt$par-af$aff) replace detail
mat drop summ_daff00_tbl summ_dcty00_tbl

* change in affiliate numbers, given initial presence (first entry not counted)
preserve
drop if year==1996
keep mneid del_naff* daff*
reshape long del_naff daff, i(mneid) j(cntrybemgrp) string
drop if del_naff==.
* gen str str_del_naff = string(del_naff)
* replace str_del_naff = ">5" if del_naff > 5
foreach reg in $regagg {
  local r2dg = substr("`reg'",1,2)
  replace cntrybemgrp = "`reg'" if cntrybemgrp=="`r2dg'"
  }
encode cntrybemgrp, gen(cntrygrp) label(cntrygrp)
* table del_naff cntrygrp, c(count mneid)
tabl2tex mneid, type(count) r(del_naff) c(cntrygrp) p(tex/pop/pt$par-af$aff) name(delnaff) fancy replace
mat drop delnaff_tbl
restore, preserve

* change in country numbers, given initial presence (first entry not counted)
drop if year==1996
keep mneid del_ncty*
reshape long del_ncty, i(mneid) j(cntrybemgrp) string
drop if del_ncty==.
* gen str str_del_ncty = string(del_ncty)
* replace str_del_ncty = ">5" if del_ncty > 5
foreach reg in $regagg {
  local r2dg = substr("`reg'",1,2)
  replace cntrybemgrp = "`reg'" if cntrybemgrp=="`r2dg'"
  }
encode cntrybemgrp, gen(cntrygrp) label(cntrygrp)
* table del_ncty cntrygrp, c(count mneid)
tabl2tex mneid, type(count) r(del_ncty) c(cntrygrp) p(tex/pop/pt$par-af$aff) name(delncty) fancy replace
mat drop delncty_tbl
restore, preserve

* change in affiliate numbers, unconditional
drop if year==1996
keep mneid deluncdl_naff* daff* reldaff*
reshape long deluncdl_naff daff reldaff, i(mneid) j(cntrybemgrp) string
drop if deluncdl_naff==.
* gen str str_deluncdl_naff = string(deluncdl_naff)
* replace str_deluncdl_naff = ">5" if deluncdl_naff > 5
foreach reg in $regagg {
  local r2dg = substr("`reg'",1,2)
  replace cntrybemgrp = "`reg'" if cntrybemgrp=="`r2dg'"
  }
encode cntrybemgrp, gen(cntrygrp) label(cntrygrp)
* table deluncdl_naff cntrygrp, c(count mneid)
tempfile daff
save `daff'
tabl2tex mneid, type(count) r(deluncdl_naff) c(cntrygrp) p(tex/pop/pt$par-af$aff) name(deluncdlnaff) fancy replace
mat drop deluncdlnaff_tbl
use `daff'
* table daff cntrygrp, c(count mneid)
tabl2tex daff, type(mean) r(deluncdl_naff) c(cntrygrp) p(tex/pop/pt$par-af$aff) name(daff) fancy replace digits(3)
mat drop daff_tbl
use `daff'
* table reldaff cntrygrp, c(count mneid)
tabl2tex reldaff, type(mean) r(deluncdl_naff) c(cntrygrp) p(tex/pop/pt$par-af$aff) name(reldaff) fancy replace digits(3)
mat drop reldaff_tbl
restore, preserve

* change in country numbers, unconditional
drop if year==1996
keep mneid deluncdl_ncty* dcty* reldcty*
reshape long deluncdl_ncty dcty reldcty, i(mneid) j(cntrybemgrp) string
drop if deluncdl_ncty==.
* gen str str_deluncdl_ncty = string(deluncdl_ncty)
* replace str_deluncdl_ncty = ">5" if deluncdl_ncty > 5
foreach reg in $regagg {
  local r2dg = substr("`reg'",1,2)
  replace cntrybemgrp = "`reg'" if cntrybemgrp=="`r2dg'"
  }
encode cntrybemgrp, gen(cntrygrp) label(cntrygrp)
* table deluncdl_ncty cntrygrp, c(count mneid)
tempfile dcty
save `dcty'
tabl2tex mneid, type(count) r(deluncdl_ncty) c(cntrygrp) p(tex/pop/pt$par-af$aff) name(deluncdlncty) fancy replace
mat drop deluncdlncty_tbl
use `dcty'
* table dcty cntrygrp, c(count mneid)
tabl2tex dcty, type(mean) r(deluncdl_ncty) c(cntrygrp) p(tex/pop/pt$par-af$aff) name(dcty) fancy replace digits(3)
mat drop dcty_tbl
use `dcty'
* table reldcty cntrygrp, c(count mneid)
tabl2tex reldcty, type(mean) r(deluncdl_ncty) c(cntrygrp) p(tex/pop/pt$par-af$aff) name(reldcty) fancy replace digits(3)
mat drop reldcty_tbl
restore


/* check whether dominant region choices */
/*---------------------------------------*/

preserve
foreach yr in 96 00 {
  restore, preserve
  keep mneid year i*
  sort mneid year
  by mneid: keep if _n==1
  drop year iHO*
  gen byte _ones = 1
  foreach reg in $regagg {
    local r2dg = substr("`reg'",1,2)
    gen str2 r`r2dg'`yr' = "`r2dg'`yr'" if i`r2dg'`yr'==1
    replace r`r2dg'`yr' = "__" if i`r2dg'`yr'==0
    drop i`r2dg'`yr'
    }
  gen str11 pattern`yr' = rCE`yr' + "." + rDE`yr' + "." + rOI`yr' + "." + rWE`yr'
  drop rCE`yr' rDE`yr' rOI`yr' rWE`yr'
  replace pattern`yr' = trim(pattern`yr')
  label var pattern`yr' "FDI Presence `yr'"
  tab pattern`yr'
  encode pattern`yr', generate(_pattern`yr') label(pattern`yr')
  * table pattern`yr', c(count mneid)
  tabl2tex mneid, type(count) r(_pattern`yr') c(_ones) p(tex/pop/pt$par-af$aff) name(pattern`yr') fancy replace
  mat drop pattern`yr'_tbl
  }
restore


/* additional pattern statistics */
/*-------------------------------*/

use `ptcntry', clear
keep firmid country year
rename firmid mneid
by mneid: egen cntrycnt = count(country)
drop country
duplicates drop
* table cntrycnt year, c(count mneid)
preserve
tabl2tex mneid, type(count) r(cntrycnt) c(year) p(tex/pop/pt$par-af$aff) name(countries_compl) fancy replace
restore
gen str _cntrycnt = string(cntrycnt)
replace _cntrycnt = ">9" if cntrycnt>9
encode _cntrycnt, gen(trunccntrycnt) label(cntrycnt)
drop _cntrycnt
tabl2tex mneid, type(count) r(trunccntrycnt) c(year) p(tex/pop/pt$par-af$aff) name(countries) fancy replace


log close
cd "$root"
