*! version 1.0.2  11dec2008  by Marc Muendler muendler@ucsd.edu
*! version 2.0.2  21jun2009  by Marc Muendler  muendler@ucsd.edu

cd "$rootslct"
clear
set mem 60m
set more off

capture mkdir "$rootslct/tex"
capture mkdir "$rootslct/tex/desc"  /* Directories unaffected if they exist */

capture log close
log using "logs/swe-wage-diff-quarts.log", replace

* Concordance NACE for Sweden and secbm
tempfile bem secbem
insheet using "$root/conc/nace2bem.csv", comma names clear
drop sec_bem_short sec_agg*
label var sec_bem "Sector codes (BEM)"
label var sec_bem_desc "Sector descriptions (BEM)"
keep nace_fix sec_bem sec_bem_desc
sort nace_fix
save `bem'
use "$root/conc/sector-conc-nace", clear
keep nace11_code
drop if nace11_code==0
duplicates drop
sort nace11_code
merge nace11_code using "$root/conc/nace2nacefix", nokeep
drop _m
sort nace_fix
merge nace_fix using `bem', nokeep
keep nace_fix sec_bem sec_bem_desc
duplicates drop
rename sec_bem sec_bem_fix
encode sec_bem_fix, gen(sec_bem) label(secbem)
keep nace_fix sec_bem
rename nace_fix sec1_fix
rename sec_bem sec1_bem
sort sec1_fix
save `secbem'

* Concordance IUI country codes with quartile groups
tempfile countryconc
use "$root/conc/countryconc-iui-buba-nodup", clear
drop country
rename buba country
sort country 
    * joinby country using "$rootslct/tex/desc/quarts/$waglvl-quartiles", unmatched(master)
    merge country using "$rootslct/tex/desc/quarts/$waglvl-quartiles", nokeep
    count if _m~=3 & country~=.
    if `r(N)' > 0 {
        disp in red "Incomplete country concordance"
        * STOP
        }
drop _merge
keep cc98 country
sort cc98
compress
save `countryconc'


/* Prepare Affiliate Data (similar to %41/#reg-pop-pattern-swe.do) */
/*-----------------------------------------------------------------*/

tempfile pardata
use mbid bran98 sni anstsve omssve bkvsve lonsve using "$root/Xiui/sa98", clear

* removal of coding errors
replace bran98=3.1 if mbid==562
replace sni=2.1 if mbid==562
replace bran98=13.3 if mbid==63
replace sni=9.2 if mbid==63
replace bran98=16 if mbid==481 | mbid==543
replace sni=15 if mbid==481 | mbid==543

gen int year = 1998
gen bran98_new=bran98*10
compress
sort bran98_new
save `pardata'

use "$root/conc/conc-sni94-bran98", clear
sort bran98_new
joinby bran98_new using `pardata', unmatched(using)
rename sweind sweind_par
order mbid year anstsve omssve bkvsve lonsve bran98_new sweind_par
keep mbid year anstsve omssve bkvsve lonsve bran98_new sweind_par

rename mbid firmid
rename anstsve employmt_par
rename omssve turnover_par
rename bkvsve fixdasst_par
rename lonsve wb_par
label var firmid "Firm ID (IUI)"
label var year "Calendar Year"
label var employmt_par "Number of employees"
label var turnover_par "Turnover"
label var fixdasst_par "Fixed assets (non-financial)"
label var wb_par       "Wage bill parent [mill. SEK]"
sort firmid year
save `pardata', replace


/* Prepare Affiliate Data (similar to %41/#reg-pop-pattern-swe.do) */
/*-----------------------------------------------------------------*/

tempfile affdata
use mbid dbid bran98db sni cc98 anstdb omsdb tillgdb bkvdb ekdb londb using "$root/Xiui/sb98", clear

* removal of coding errors
replace bran98db=3.1 if mbid==562
replace sni=2.1 if mbid==562
replace bran98db=13.3 if mbid==63
replace sni=9.2 if mbid==63
replace bran98db=16 if mbid==481 | mbid==543
replace sni=15 if mbid==481 | mbid==543

gen int year = 1998
gen bran98db_new=bran98db*10
compress
sort bran98db_new
save `affdata'

use "$root/conc/conc-sni94-bran98", clear
rename bran98_new bran98db_new
sort bran98db_new
joinby bran98db_new using `affdata', unmatched(using)
rename sweind sweind_aff
order mbid dbid year anstdb omsdb tillgdb bkvdb ekdb londb cc98 bran98db_new sweind_aff
keep mbid dbid year anstdb omsdb tillgdb bkvdb ekdb londb cc98 bran98db_new sweind_aff

rename mbid firmid
rename dbid affil2id
rename anstdb employmt
rename omsdb turnover
rename tillgdb assettot
rename bkvdb fixdasst
rename ekdb equity
rename londb wb
label var firmid "Firm ID (IUI)"
label var year "Calendar Year"
label var affil2id "Foreign Affiliate (IUI ID)"
label var employmt "Number of employees"
label var turnover "Turnover"
label var assettot "Balance sheet total"
label var fixdasst "Fixed assets (non-financial)"
label var equity   "Equity (incl. ret. profits)"
label var wb       "Wage bill affiliate [mill. SEK]"
sort firmid year affil2id
save `affdata', replace


/* Data Treatments */
/*-----------------*/

use `affdata', clear
merge firmid year using `pardata'
tab _m
drop if _m==2
count if _m~=3
if `r(N)'>0  STOP  // incomplete affiliate match
drop _merge

* keep proper countries only
drop if cc98<11
drop if cc98==.

* concord parent with nace and secbem
rename sweind_par sweind
sort sweind
joinby sweind using "$root/conc/iuisector.dta", unmatched(master)
drop if bran98_new==10 & nace~=13
drop if bran98_new==31 & nace~=18
    count if _m~=3 & bran98~=.
    if `r(N)' > 0 {
        disp as err "Incomplete industry concordance"
        STOP
        }
    drop sweind _merge bran98 bran98_desc nace nace_fix_desc secbem sni98 sni2002
rename nace_fix sec1_fix
label var sec1_fix "Sector of Swedish parent"

* concord affiliates with nace and secbem
rename sweind_aff sweind
sort sweind
joinby sweind using "$root/conc/iuisector.dta", unmatched(master)
drop if bran98db_new==10 & nace~=13
drop if bran98db_new==31 & nace~=18
    count if _m~=3 & bran98~=.
    if `r(N)' > 0 {
        disp as err "Incomplete industry concordance"
        STOP
        }
    drop sweind  _merge bran98 bran98_desc nace nace_fix_desc secbem sni98 sni2002
rename nace_fix sec2_fix
label var sec2_fix "Sector of foreign affiliate"

* concord IUI data with country group codes
sort cc98
merge cc98 using `countryconc', nokeep
qui count if _merge==3
if  `r(N)'~=_N {
  disp as err "Incomplete merge"
  STOP
  }
drop _merge
label var country "Country of affiliate"
drop cc98

replace country = 102 if country == 2 // Belgium
replace country = 104 if country == 4 // Luxembourg
* replace country =  46 if country == // Malta
* replace country =  94 if country == // Yugoslavia 
* replace country = 288 if country == // Nigeria
* replace country = 424 if country == // Honduras
* replace country = 472 if country == // Trinidad and Tobago

order firmid affil2id year country sec1_fix sec2_fix
sort firmid affil2id year


/* Sectoral wage premia */
/*----------------------*/

preserve
  tempfile parseclvl
  collapse (sum) wb_par employmt_par, by(sec1_fix) fast
  gen wage = wb_par / employmt_par
  replace wage = . if wage==0
  gen country = 30
  keep wage country sec1_fix
  sort country sec1_fix
  * conversion to EUR 12-31-1998
  rename wage wage_eur
  replace wage_eur = wage_eur * 110000
  rename country bubakey
  label var bubakey "Two-digit BuBa country number"
  label var wage_eur "Avg. Swedish MNE wages [EUR]"
  qui do "$root/conc/land.do"
  label values bubakey land
  order bubakey sec1_fix
  sort bubakey sec1_fix
  save `parseclvl'
restore, preserve
  tempfile affseclvl
  collapse (sum) wb employmt, by(country sec1_fix) fast
  gen wage = wb / employmt
  replace wage = . if wage==0
  keep wage country sec1_fix
  sort country sec1_fix
  * conversion to EUR 12-31-1998
  rename wage wage_eur
  replace wage_eur = wage_eur * 110000
  rename country bubakey
  label var bubakey "Two-digit BuBa country number"
  label var wage_eur "Avg. Swedish MNE wages [EUR]"
  qui do "$root/conc/land.do"
  label values bubakey land
  order bubakey sec1_fix
  sort bubakey sec1_fix
  save `affseclvl'
restore, preserve
  use country wage_ppp quartile using "$rootslct/tex/desc/quarts/pt$par-af$aff-$waglvl-1998.dta", clear
  rename country bubakey
  sort bubakey
  joinby bubakey using `affseclvl', unmatched(both) _merge(_merge)
  tab _m
  tab bubakey if _merge==1 & bubakey~=30 // only in master data (unido)
  tab bubakey if _merge==2 & bubakey~=30 // only in using data (iui)
  drop _m
  sort bubakey sec1_fix
  joinby bubakey using `parseclvl', unmatched(both) _merge(_merge) update
  tab _m
  drop _m
  gen wage_premium = wage_eur / wage_ppp
  drop wage_eur 
  keep if wage_premium~=. & wage_premium~=0
  drop wage_ppp
  order bubakey sec1_fix wage_premium
  label define enbubalo 0 "Germany", modify
  label var wage_premium "Swedish MNE wage / country wage"
  drop quartile
  save "tex/desc/wagediffs/swediffs-$waglvl-1998-quarts.dta", replace
  rename wage_premium wdif
  rename bubakey country

  sort country
  merge country using "$rootslct/tex/desc/quarts/$waglvl-quartiles", nokeep
  drop if country==0   // remove Germany from EMU/WEU
  drop if quartile==.  // countries with Swedish MNE affiliates but no external wage information for quartiles
  foreach var in wdif {
    replace `var'=ln(`var')
    }
  drop country _merge
  sort sec1_fix
  merge sec1_fix using `secbem', nokeep
  tab _m
  count if _m~=3
  if `r(N)'~=0  STOP
  collapse (mean) wdif, by(sec1_bem quartile) fast
  decode quartile, generate(_quartile)
  drop quartile
  reshape wide wdif, i(sec1_bem) j(_quartile) string
  foreach reg of global regqrt {
    egen _wdif`reg' = mean(wdif`reg')
    replace wdif`reg'=_wdif`reg' if wdif`reg'==.  // replace missing sector information with cross-sector mean
    drop _wdif`reg'
    label var wdif`reg' "Mean Log Wage premium `reg'"
    }
  sort sec1_bem
  save "tex/desc/wagediffs/swediffs-$waglvl-1998-quartile-quarts.dta", replace
restore


/* Table of wage premia */
/*----------------------*/

preserve
  tempfile parlvl
  collapse (sum) wb_par employmt_par, fast
  gen wage = wb_par / employmt_par
  replace wage = . if wage==0
  gen country = 30
  keep wage country
  sort country 
  * conversion to EUR 12-31-1998
  rename wage wage_eur
  replace wage_eur = wage_eur * 110000
  rename country bubakey
  label var bubakey "Two-digit BuBa country number"
  label var wage_eur "Avg. Swedish MNE wages [EUR]"
  qui do "$root/conc/land.do"
  label values bubakey land
  order bubakey
  sort bubakey
  save `parlvl'
restore, preserve
  tempfile afflvl
  collapse (sum) wb employmt, by(country) fast
  gen wage = wb / employmt
  replace wage = . if wage==0
  keep wage country
  sort country 
  * conversion to EUR 12-31-1998
  rename wage wage_eur
  replace wage_eur = wage_eur * 110000
  rename country bubakey
  label var bubakey "Two-digit BuBa country number"
  label var wage_eur "Avg. Swedish MNE wages [EUR]"
  qui do "$root/conc/land.do"
  label values bubakey land
  order bubakey
  sort bubakey
  save `afflvl'
restore, preserve
  tempfile all col2
  use country wage_ppp quartile using "$rootslct/tex/desc/quarts/pt$par-af$aff-$waglvl-1998.dta", clear
  rename country bubakey
  sort bubakey
  merge bubakey using `afflvl'
  tab _m
  drop _m
  sort bubakey
  merge bubakey using `parlvl', update
  tab _m
  drop _m
  gen wage_premium = wage_eur / wage_ppp
  drop wage_eur
  keep if wage_premium~=. & wage_premium~=0
  gsort -wage_premium
  drop wage_ppp
  order bubakey wage_premium quartile
  label define enbubalo 0 "Germany", modify
  decode bubakey, generate(_rowname)
  replace _rowname = trim(substr(_rowname,1,index(_rowname," ("))) if index(_rowname," (")>0
  replace quartile = 5 - quartile
  replace quartile = 4 if bubakey==0
  gen _quartile = string(quartile)
  drop quartile
  rename _quartile quartile
  keep _rowname wage_premium quartile
  order _rowname wage_premium quartile
  qui count
  local tot = `r(N)'
  gsort -wage_premium
  save `all'
  use `all'
  keep if _n>int(`tot'/2+.5)
  rename _rowname _rowname2
  rename wage_premium wage_premium2
  rename quartile quartile2
  gsort -wage_premium2
  save `col2'
  use `all'
  keep if _n<=int(`tot'/2+.5)
  rename _rowname _rowname1
  rename wage_premium wage_premium1
  rename quartile quartile1
  gsort -wage_premium1
  merge using `col2'
  compress
  drop _m
  save "tex/pop/pt$par-af$aff/swediffs-$waglvl-1998-quarts.dta", replace
  gen str _wage_premium1 = string(int(wage_premium1*100+.5)/100)
  gen str _wage_premium2 = string(int(wage_premium2*100+.5)/100)
  drop wage_premium1 wage_premium2
  rename _wage_premium1 wage_premium1
  rename _wage_premium2 wage_premium2
  order _rowname1 wage_premium1 quartile1 _rowname2 wage_premium2 quartile2
  foreach var in _rowname1 wage_premium1 quartile1 _rowname2 wage_premium2 {
    replace `var' = `var' + " &"
    }
  replace quartile1 = quartile1 + "&"
  replace quartile2 = quartile2 + " \" + "\"
  outsheet using "tex/pop/pt$par-af$aff/swediffs-$waglvl-1998-quarts.tex", noquote nonames replace
restore

log close
