*! version 1.0.4  10mar2006  by Marc Muendler  muendler@ucsd.edu

local tlogyr = substr("${tlogyear}",3,2)
local selyr = substr("${selyear}",3,2)
if "$dpref"==""  global dpref = "$dp"

capture mkdir "tex/desc"
capture mkdir "tex/desc/wagediffs"

clear
set memory 500m
set matsize 400
set more off

cd "$rootslct"

tempfile wdi cntrgrpbem concnace ubs`selyr' ubs99 ubs`tlogyr' homubs`selyr' homubs99 homubs`tlogyr' homsecwag swe98 homswe98 cntrgrp_med_wage_`tlogyr' cntrgrp_med_wage_`selyr'

* Country group resetting
capture program drop countrygrp_bem
program define countrygrp_bem
  * Apply BEM cntrybemgrp definitions
  /*-----------------------
   WEU: EMU (3), OWE (6);
   OIN: OIN (5);
   CEE: CEE (2); 
   DEV: APC (1), ODV (4) and RCA (7)
   --------------------------------------------*/
  tab cntrygrp_bem
  gen str3 cntrybemgrp = "CEE" if cntrygrp_bem=="CEE"
  replace  cntrybemgrp = "DEV" if cntrygrp_bem=="APC" | cntrygrp_bem=="ODV" | cntrygrp_bem=="OTR" | cntrygrp_bem=="RCA"
  replace  cntrybemgrp = "OIN" if cntrygrp_bem=="OIN"
  replace  cntrybemgrp = "WEU" if cntrygrp_bem=="EMU" | cntrygrp_bem=="OWE"
  label var cntrybemgrp "Country group BEM"
  rename cntrybemgrp _cntrybemgrp
  encode _cntrybemgrp, gen(cntrybemgrp) label(cntrybem)
  drop _cntrybemgrp
end


/* External data preperation  */
/*----------------------------*/

use "$root/countries/extdata-deflated", clear
keep if year==1999
keep country population
sort country
save `wdi'

use "$root/conc/cntry2bemgrp", clear
rename bubakey country
sort country
compress
save `cntrgrpbem'

use "$root/conc/sector-conc-nace", clear
sort nace11_code
compress
save `concnace'

global ubs`selyr' "`ubs`selyr''"
global ubs99 "`ubs99'"
global ubs`tlogyr' "`ubs`tlogyr''"
global swe98 "`swe98'"
global homubs`selyr' "`homubs`selyr''"
global homubs99 "`homubs99'"
global homubs`tlogyr' "`homubs`tlogyr''"
global homswe98 "`homswe98'"
global homsecwag "`homsecwag'"
do $dpref/#translog-ubswages.do


/*------------------------------*/
/* Construct wage differentials */
/*------------------------------*/

* Regional mean of median wages ${tlogyear}
*------------------------------------------
use `ubs`tlogyr'', clear
drop if cntr_wage==.
sort country 
merge country using `wdi', nokeep
tab _merge
list country population cntr_wage if _merge==1 /* _merge==1 is Germany */
drop if country==0
drop _merge
sort country 
merge country using `cntrgrpbem' 
tab _merge
keep if _merge==3
drop _merge
countrygrp_bem
collapse (mean) cntr_wage [pw=population], by(cntrybemgrp) fast
rename cntr_wage cntrgrp_wage
label var cntrgrp_wage "Regional mean wage ${tlogyear}"
gen int year = ${tlogyear}
sort year
merge year using `homubs`tlogyr'', nokeep
drop year _m
rename cntr_wage_par home_wage_par
sort cntrybemgrp
save `cntrgrp_med_wage_`tlogyr''

* Regional mean of median wages ${selyear}
*-----------------------------------------
use `ubs`selyr'', clear
drop if cntr_wage==.
sort country 
merge country using `wdi', nokeep
tab _merge
list country population cntr_wage if _merge==1 /* _merge==1 is Germany */
drop if country==0
drop _merge
sort country 
merge country using `cntrgrpbem' 
tab _merge
keep if _merge==3
drop _merge
countrygrp_bem
collapse (mean) cntr_wage [pw=population], by(cntrybemgrp) fast
rename cntr_wage cntrgrp_wage
label var cntrgrp_wage "Regional mean wage ${selyear}"
gen int year = ${selyear}
sort year
merge year using `homubs`selyr'', nokeep
drop year _m
rename cntr_wage_par home_wage_par
sort cntrybemgrp
save `cntrgrp_med_wage_`selyr''


* Wage differential in year of translog estimation ${tlogyear}
*-------------------------------------------------------------
use "$root/wages/destatis-gearn-defl", clear
keep if year==${tlogyear}
drop agearn year
rename nace11 nace1
* replace missing with mean aggregate sector wage
gen byte _aggsec = int(nace1/10)
egen _agearn = mean(agearn), by(_aggsec)
replace agearn = _agearn if agearn==.
drop _*
* merge in countries
qui count
local obs = `r(N)'
expand 4
sort nace1
gen cntrybemgrp = _n - int(_n/4-.1)*4
sort cntrybemgrp
merge cntrybemgrp using `cntrgrp_med_wage_`tlogyr''
tab _merge
drop _merge
* wagediffs and German ln wages
gen wagediff=cntrgrp_wage/agearn_med
gen ubsdiff =cntrgrp_wage/home_wage_par
label var wagediff "cntrgrp_wage/agearn_med"
label var ubsdiff  "cntrgrp_wage/home_w"
gen ln_wagediff=ln(wagediff)
gen ln_ubsdiff=ln(wagediff)
label var ln_wagediff "ln(cntrgrp_wage/agearn_med)"
label var ln_ubsdiff "ln(cntrgrp_wage/home_w)"
local i 0
foreach var in wagediff ln_wagediff ubsdiff ln_ubsdiff {
  local i = `i' + 1
  local lbl`i' : variable label `var'
  }
replace agearn_med = ln(agearn_med)
rename agearn_med w_HOM
label var w_HOM "ln Sectoral median wage"
keep nace1 cntrybemgrp wagediff ln_wagediff ubsdiff ln_ubsdiff w_HOM
preserve
  gen year=${tlogyear}
  sort year cntrybemgrp nace1
  save ${bef_reshape_${tlogyear}}
restore
reshape wide wagediff ln_wagediff ubsdiff ln_ubsdiff, i(nace1 w_HOM) j(cntrybemgrp)
local x=0
foreach name in $regagg {
  local x=`x'+1
  local i 0
  foreach var in wagediff ln_wagediff ubsdiff ln_ubsdiff {
    local i = `i' + 1
    rename `var'`x' `var'_`name' 
    label var `var'_`name' "`lbl`i'' `name'"
    }
  }
sort nace1
save ${wage_diff_${tlogyear}}
* aggregate reporting with table
rename nace1 nace11_code
sort nace11_code
merge nace11_code using "$root/conc/nace2bem", nokeep
collapse (mean) wagediff* ubsdiff*, by(sec_bem) fast
keep sec_bem wagediff* ubsdiff*
preserve 
  tempfile appndtlg
  keep sec_bem ubsdiff*
  keep in 1
  foreach reg in $regagg {
    rename ubsdiff_`reg' wagediff_`reg'
    }
  replace sec_bem = 0
  save `appndtlg'
restore
keep sec_bem wagediff*
append using `appndtlg'
label define secbem 0 "Country-wide UBS wage", modify
rename sec_bem _rowname
save "tex/desc/wagediffs/diffsger`tlogyr'-$waglvl", replace
* matload diffsger`tlogyr', p(tex/desc/wagediffs) over dropall missing(.)
qui do "$root/conc/secbem.do"


* Wage differential in year of selection estimation ${selyear}
*-------------------------------------------------------------
use "$root/wages/destatis-gearn-defl", clear
keep if year==${selyear}
drop agearn year
rename nace11 nace1
* replace missing with mean aggregate sector wage
gen byte _aggsec = int(nace1/10)
egen _agearn = mean(agearn), by(_aggsec)
replace agearn = _agearn if agearn==.
drop _*
* merge in countries
qui count
local obs = `r(N)'
expand 4
sort nace1
gen cntrybemgrp = _n - int(_n/4-.1)*4
sort cntrybemgrp
merge cntrybemgrp using `cntrgrp_med_wage_`selyr''
tab _merge
drop _merge
* wagediffs and German ln wages
gen wagediff=cntrgrp_wage/agearn_med
gen ubsdiff =cntrgrp_wage/home_wage_par
label var wagediff "cntrgrp_wage/agearn_med"
label var ubsdiff  "cntrgrp_wage/home_w"
gen ln_wagediff=ln(wagediff)
gen ln_ubsdiff=ln(wagediff)
label var ln_wagediff "ln(cntrgrp_wage/agearn_med)"
label var ln_ubsdiff "ln(cntrgrp_wage/home_w)"
local i 0
foreach var in wagediff ln_wagediff ubsdiff ln_ubsdiff {
  local i = `i' + 1
  local lbl`i' : variable label `var'
  }
replace agearn_med = ln(agearn_med)
rename agearn_med w_HOM
label var w_HOM "ln Sectoral median wage"
keep nace1 cntrybemgrp wagediff ln_wagediff ubsdiff ln_ubsdiff w_HOM
preserve
  gen year=${selyear}
  sort year cntrybemgrp nace1
  save ${bef_reshape_${selyear}}
restore
reshape wide wagediff ln_wagediff ubsdiff ln_ubsdiff, i(nace1 w_HOM) j(cntrybemgrp)
local x=0
foreach name in $regagg {
  local x=`x'+1
  local i 0
  foreach var in wagediff ln_wagediff ubsdiff ln_ubsdiff {
    local i = `i' + 1
    rename `var'`x' `var'_`name' 
    label var `var'_`name' "`lbl`i'' `name'"
    }
  }
sort nace1
save ${wage_diff_${selyear}}
* aggregate reporting with table
rename nace1 nace11_code
sort nace11_code
merge nace11_code using "$root/conc/nace2bem", nokeep
collapse (mean) wagediff* ubsdiff*, by(sec_bem) fast
keep sec_bem wagediff* ubsdiff*
preserve 
  tempfile appndsel
  keep sec_bem ubsdiff*
  keep in 1
  foreach reg in $regagg {
    rename ubsdiff_`reg' wagediff_`reg'
    }
  replace sec_bem = 0
  save `appndsel'
restore
keep sec_bem wagediff*
append using `appndsel'
label define secbem 0 "Country-wide UBS wage", modify
rename sec_bem _rowname
save "tex/desc/wagediffs/diffsger`selyr'-$waglvl", replace
* matload diffsger`selyr', p(tex/desc/wagediffs) over dropall missing(.)
qui do "$root/conc/secbem.do"
