*! version 1.1.5  30jan2006  by Marc Muendler  muendler@ucsd.edu

clear
set memory 500m
set more off

cd "$rootslct"

capture log close
log using "logs/prep-parent-hostcntry-data-selct-pt$par-af$aff-allyrs.log", replace


*----------------------following code identical to prep-translog-fdidata.do---------------------------------------------
*-----substitute: allyrs for 96&00--------------------------------------------------------------------


/* External files */
/*----------------*/

tempfile naceconc
tempfile secfix
global secfix "`secfix'"

use "$root/conc/sector-conc-nace", clear
sort buba_code
save `naceconc'

do "$dpref/#sector-definitions.do"


/* Affiliate Data with Sector and Country definitions */
/*----------------------------------------------------*/

use "$rootslct/Xdata/affils-fdi-ustan-allyrs-plaineur", clear
label var standalone "Indic.: No domestic match"
keep firmid affil2id year country share standalone consol_par nace1 sec1 sec2_fix employmt* turnover* assettot* fixdasst* equity* liab_par profits_par exports_par wb* ustan
order firmid affil2id year country share standalone consol_par nace1 sec1 sec2_fix employmt* turnover* assettot* fixdasst* equity* liab_par profits_par exports_par wb* ustan
sort firmid affil2id year

keep if share > $share

* country_grp definitions (as in swe-ger-conc.do)
foreach var in country {
    * tab `var'
    rename `var' bubakey
    sort bubakey
    merge bubakey using "$root/conc/cntry2bemgrp", nokeep
    count if _m~=3 & bubakey~=.
    if `r(N)' > 0 {
        disp as err "Incomplete country concordance"
        STOP
        }
    rename bubakey `var'
    rename cntrygrp_bem `var'grp_fix
    drop _merge
    }
rename countrygrp_fix cntrygrp_bem
label var cntrygrp_bem "Country group of affiliate"
sort firmid affil2id year

* sector and country resetting (similar to prep-summarize-affils.do)
do "$dpref/#sector-country-resetting.do"

keep firmid affil2id year country share cntrybemgrp standalone consol_par nace1 sec1_bem sec1_aggbem sec2_bem sec2_aggbem employmt* turnover* assettot* fixdasst* equity* liab_par profits_par exports_par wb* ustan
order firmid affil2id year country share cntrybemgrp standalone consol_par nace1 sec1_bem sec1_aggbem sec2_bem sec2_aggbem employmt* turnover* assettot* fixdasst* equity* liab_par profits_par exports_par wb* ustan

if "$par" == "manf" {
  keep if sec1_aggbem>=2 & sec1_aggbem<=4
  }
if "$par" == "nonmf" {
  drop if sec1_aggbem>=2 & sec1_aggbem<=4
  }

if "$aff" == "manf" {
  keep if sec2_aggbem>=2 & sec2_aggbem<=4
  }
if "$aff" == "nonmf" {
  drop if sec2_aggbem>=2 & sec2_aggbem<=4
  }


/* Unweighted affiliate data */
/*---------------------------*/

foreach var in turnover assettot fixdasst equity {
    capture drop `var'_lcu
    capture drop `var'_lcu
    }
label var turnover_ppp "Turnover [ppp]"
compress 

* No treatment of duplicate information needed since majority-owned affiliates are unique


/* Host country aggregation */
/*--------------------------*/

#delimit ;
sort firmid country year;
local i = 0;
foreach var of varlist 
            employmt wb_ppp
            turnover turnover_ppp 
            fixdasst fixdasst_ppp 
            assettot assettot_ppp 
            equity equity_ppp 
            employmt_par wb_par
            turnover_par fixdasst_par assettot_par 
            equity_par liab_par profits_par exports_par 
            ustan nace1 sec1_bem sec1_aggbem standalone consol_par {;
  local i = `i' + 1;
  local lbl`i' : variable label `var';
  };
collapse (sum) employmt wb_ppp
               turnover turnover_ppp 
               fixdasst fixdasst_ppp 
               assettot assettot_ppp 
               equity equity_ppp 
       (count) numaffil=affil2id 
         (max) employmt_par wb_par
               turnover_par fixdasst_par assettot_par 
               equity_par liab_par profits_par exports_par 
               ustan nace1 sec1_bem sec1_aggbem standalone consol_par,
           by (firmid country year) fast;
local i = 0;
foreach var of varlist 
            employmt wb_ppp
            turnover turnover_ppp 
            fixdasst fixdasst_ppp 
            assettot assettot_ppp 
            equity equity_ppp 
            employmt_par wb_par
            turnover_par fixdasst_par assettot_par 
            equity_par liab_par profits_par exports_par 
            ustan nace1 sec1_bem sec1_aggbem standalone consol_par {;
  local i = `i' + 1;
  label variable `var' "`lbl`i''";
  };
label var numaffil "Count of Affiliates";
foreach var of varlist fixdasst_ppp equity_ppp turnover_ppp employmt assettot_ppp wb_ppp {;
  replace `var'=. if `var'==0;
  };
compress;
#delimit cr                     

/*-----------------------------------------------------------------------------------------------
  Caution:
  All zero entries are set to missing since the command collapse (sum) changes missing to zero.
-------------------------------------------------------------------------------------------------*/


/* Buch et al. internationalisation index: Number of countries where a firm is active */
/*------------------------------------------------------------------------------------*/
tempfile intlindx
preserve 
  duplicates drop firmid country year, force
  duplicates tag firmid year, gen(_help)
  replace _help=_help+1
  sort firmid year
  collapse (count) inter=_help, by(firmid year)
  replace inter=inter+1
  label var inter "Internationalization (counts +1)"
  sort firmid year
  save `intlindx'
restore
sort firmid year
merge firmid year using `intlindx', nokeep
drop _merge


/* Finalize */
/*----------*/

qui do "$root/conc/secbem.do"
label values sec1_bem secbem
order firmid ustan country year 
sort firmid country year 
compress

*----------------------above code identical to prep-translog-fdidata.do---------------------------------------------

save "$rootslct/Xdata/data-parent-hostcntry-pt$par-af$aff-allyrs", replace
desc
ci

log close
cd "$root"
