*! version 1.0.1  02mar2005  by Robert Jaeckle   jaeckle@ifo.de
*! version 1.1.1  03aug2005  by Karolina Ekholm  neke@hhs.se
*! version 2.0.1  15jan2006  by Marc Muendler    muendler@ucsd.edu

clear
set memory 500m
set more off
capture log close

capture mkdir "$rootslct/tex/desc"
capture mkdir "$rootslct/tex/desc/pt$par-af$aff"  /* Directories unaffected if they exist */

cd "$rootslct"
log using "logs/prep-translog-fdi-data-$waglvl-pt$par-af$aff.log", replace


/* External data preperation */
/*---------------------------*/

tempfile iso3buba cntrgrpbem

use "$root/conc/fdi-iso-country", clear
rename buba country
keep iso3code country 
sort country
compress
save `iso3buba'

use "$root/conc/cntry2bemgrp", clear
rename bubakey country
sort country
compress
save `cntrgrpbem'


/* Work data at Parent Host-country Year level */
/*---------------------------------------------*/

foreach year in 1996 2000 {

global tlogyear = 2000
global selyear  = 1996
local wfl = substr("${waglvl}",4,3)
if "`wfl'"=="swe"  local wfl "oww"
global year `year'
* extra years for compatibility with prep-mvprobit-med-wagediff.do
tempfile `wfl'96 `wfl'99 `wfl'00 hom`wfl'96 hom`wfl'99 hom`wfl'00 homsecwag swe98 homswe98
global `wfl'96 "``wfl'96'"
global `wfl'99 "``wfl'99'"
global `wfl'00 "``wfl'00'"
global swe98 "`swe98'"
global hom`wfl'96 "`hom`wfl'96'"
global hom`wfl'99 "`hom`wfl'99'"
global hom`wfl'00 "`hom`wfl'00'"
global homswe98 "`homswe98'"
global homsecwag "`homsecwag'"
do $dpref/#translog-`wfl'wages.do

use "$rootslct/Xdata/data-parent-hostcntry-pt$par-af$aff", clear
keep if year==`year'

order firmid ustan nace1 sec1_bem country year
sort country
merge country using `iso3buba', nokeep
tab _m
drop _m
sort country
merge country using `cntrgrpbem', nokeep
tab _m
keep firmid ustan iso3code country cntrygrp_bem nace1 sec1_bem sec1_aggbem year turnover_par turnover_ppp employmt_par employmt wb_par wb_ppp fixdasst_par fixdasst_ppp numaffil
order firmid ustan iso3code country cntrygrp_bem nace1 sec1_bem sec1_aggbem year turnover_par turnover_ppp employmt_par employmt wb_par wb_ppp fixdasst_par fixdasst_ppp numaffil


* Apply BEM cntrybemgrp definitions
/*-----------------------
 WEU: EMU (3), OWE (6);
 OIN: OIN (5);
 CEE: CEE (2); 
 DEV: APC (1), ODV (4) and RCA (7)
 --------------------------------------------*/
tab cntrygrp_bem
order firmid ustan country cntrygrp_bem
gen str3 cntrybemgrp = "CEE" if cntrygrp_bem=="CEE"
replace  cntrybemgrp = "DEV" if cntrygrp_bem=="APC" | cntrygrp_bem=="ODV" | cntrygrp_bem=="OTR" | cntrygrp_bem=="RCA"
replace  cntrybemgrp = "OIN" if cntrygrp_bem=="OIN"
replace  cntrybemgrp = "WEU" if cntrygrp_bem=="EMU" | cntrygrp_bem=="OWE"
label var cntrybemgrp "Country group BEM"
rename cntrybemgrp _cntrybemgrp
encode _cntrybemgrp, gen(cntrybemgrp) label(cntrybem)
drop _cntrybemgrp


/* Merge external wage data, keep only relevant year */
/*---------------------------------------------------*/

if substr("$waglvl",4,3)=="oww" | substr("$waglvl",4,3)=="ubs" | substr("$waglvl",4,3)=="uno" {  /* wb_par wb_ppp wage_par wage_ppp mhomwage */
  do $dpref/#translog-yearselect-wages.do
  }
if substr("$waglvl",4,3)=="swe" {  /* wb_par wb_ppp wage_par wage_ppp */
  do $dpref/#translog-avgswe-wages.do
  }
if substr("$waglvl",4,3)=="mne" {  /* wb_par wb_ppp wage_par wage_ppp */
  gen wage_ppp = wb_ppp / employmt
  gen wage_par = wb_par / employmt_par 
  }
  
keep firmid ustan year country cntrybemgrp iso3code nace1 sec1_bem sec1_aggbem fixdasst_par turnover_par employmt_par fixdasst_ppp turnover_ppp employmt numaffil wb_par wb_ppp wage_par wage_ppp 
order firmid ustan year country cntrybemgrp iso3code nace1 sec1_bem sec1_aggbem fixdasst_par turnover_par employmt_par fixdasst_ppp turnover_ppp employmt numaffil wb_par wb_ppp wage_par wage_ppp
sort firmid country year
bysort year: summ wb_par wb_ppp wage_par wage_ppp


/* Data adjustment */
/*-------------------
To create the dependent variable:
Compute the wagesum(ir) in region r as wage(r) * employment(ir)
the world-wide wage sum (i) = sum of the wage sum in the 5 regions of the world
Then, wagecostshare(ir) = wage sum(ir) / wagesum(i)

To create the explantory variables:
-- total turnover t(r) is total turnover in region r
-- input data are at firm-country level in the following form:
   firmid country wage wage_par employmt employmt_par turnover turnover_par 
-- fixed assets enter as controls

Instead of wage(r), as in our equation (2), Braconier & Ekholm use wage(ir) 
They do not use X-equation restrictions
----------------------------------------------------------------------------*/

* Transform data to MNE level
* A dataset with R+1 lines per firm results, where R is the number of foreign in which the MNE operates and "1" stands for Home

rename firmid firm

tempfile hom
preserve
     keep if employmt_par~=.
     keep firm nace1 sec1_bem employmt_par fixdasst_par turnover_par wage_par wb_par
     gen byte cntrybemgrp = 0
     foreach var in employmt fixdasst turnover wage wb { 
       rename `var'_par `var'
       }
     duplicates drop
     duplicates tag firm, gen(_chk)
     count if _chk>=1
     if `r(N)' > 0 {
       disp as err "MNEs with contradictory home information"
       STOP
       }
     drop _chk
     compress
     sort firm
     save `hom'
 restore
     keep firm nace1 sec1_bem cntrybemgrp country employmt fixdasst_ppp turnover_ppp wage_ppp wb_ppp numaffil
     foreach var in fixdasst turnover wage wb {
       rename `var'_ppp `var'
       }
     duplicates drop
     compress
     sort firm
append using `hom'
label define cntrybem 0 "HOM", modify


/* Save employment pattern in sample (missing not removed yet) */
/*-------------------------------------------------------------*/

preserve
  collapse (sum) tot_employmt=employmt (mean) mean_employmt=employmt (count) obs_count=employmt, by(cntrybemgrp) fast
  label var cntrybemgrp "Country group BEM"
  label var tot_employmt "Total Employment"
  label var mean_employmt "Mean Employment"
  label var obs_count "Number of affiliates"
  order cntrybemgrp tot_employmt mean_employmt obs_count
  sort cntrybemgrp
  compress
  save "$rootslct/tex/desc/pt$par-af$aff/employment-aggregates-`year'", replace
restore

* Drop parents and affiliates for which any of the variables 
* wage, fixdasst, employt, turnover are missing (wage is treated below)
keep if fixdasst~=.
keep if employmt~=.
keep if turnover~=.


/* Construct cost shares from alternative wage levels */
/*----------------------------------------------------*/

# delimit ;

if substr("$waglvl",1,6)=="frmmne" {;
  keep if wb~=.;
  drop wage;
  gen wage = wb/employmt;
  drop wb;
};

if substr("$waglvl",1,3)=="frm" {;
  keep if wage~=.;
  gen wsum = wage * employmt;
  sort firm cntrybemgrp;

  * firm-specific wage and factor sums by region;
  by firm cntrybemgrp: egen reg_numaffil=sum(numaffil);
  by firm cntrybemgrp: egen reg_employmt=sum(employmt);
  by firm cntrybemgrp: egen reg_fixdasst=sum(fixdasst);
  by firm cntrybemgrp: egen reg_turnover=sum(turnover);
  by firm cntrybemgrp: egen reg_wsum=sum(wsum);

  * firm-specific wage sum worldwide;
  by firm: egen world_wsum=sum(wsum);

  * firm-specific wage by region;
  gen reg_wage = reg_wsum / reg_employmt;

  * firm-specific cost share of labour by region;
  gen reg_share = reg_wsum / world_wsum;
  gen corr_fact = world_wsum / reg_wage;
  bysort firm cntrybemgrp: keep if _n==1;
  keep reg* corr* firm nace1 sec1_bem cntrybemgrp;
};

if substr("$waglvl",1,6)=="regmne" {;
  keep if wb_ppp~=.;
  drop wage;
  gen wage = wb_ppp/employmt;
  drop wb_ppp;
};

if substr("$waglvl",1,3)=="reg" {;
  keep if wage~=.;
  * firm-specific variables and median wages by region (median wages based on firm-level frequencies);
  collapse (sum) reg_numaffil=numaffil reg_employmt=employmt reg_fixdasst=fixdasst reg_turnover=turnover (median) reg_wage=wage, by(firm nace1 sec1_bem cntrybemgrp) fast;

  * firm-specific wage sum worldwide;
  gen reg_wsum = reg_wage * reg_employmt;
  by firm: egen world_wsum=sum(reg_wsum);

  * firm-specific cost of labour by region;
  gen reg_share = reg_wsum / world_wsum;
  gen corr_fact = world_wsum / reg_wage;

  bysort firm cntrybemgrp: keep if _n==1;
  keep reg* corr* firm nace1 sec1_bem cntrybemgrp;
  drop reg_wsum;
};

  rename reg_share    s;
  rename reg_wage     w;
  rename reg_turnover t;
  rename reg_fixdasst k;
  rename reg_employmt l;
  rename reg_numaffil naff;
  rename corr_fact    cf;

  foreach var in w t k l {;
    replace `var'=ln(`var');
  };

keep s w t k l naff cf firm sec1_bem cntrybemgrp;


/* Data structure at this point:
firm    cntrybemgrp  s   w    t    k   l

RJ AG   HOM      0.2 
RJ AG   CEE      0.3 
RJ AG   OIN      0.5 

SB AG   HOM      0.2 
SB AG   CEE      0.3 
SB AG   OIN      0.2 
SB AG   WEU      0.2 
SB AG   DEV      0.1 
*/

fillin firm cntrybemgrp;

bysort firm: egen nobs=count(cntrybemgrp);
tab nobs;
count if nobs~=5;
    if `r(N)' > 0 {;
        disp as err "wrong number of observations";
        STOP;
        };
drop nobs;

rename firm mneid;
sort mneid;
by mneid: egen _sec = mean(sec1_bem);
replace sec1_bem = _sec if sec1_bem==.;
tab _sec;
drop _sec;


/* Clean-up */
by mneid: egen nreg=sum(_fillin);
replace nreg=5-nreg;
drop if nreg==1; /* drop all MNEs that have only data for one region, including home */
rename _fillin nofdi;
rename cntrybemgrp _cntrybemgrp;
decode _cntrybemgrp, gen(cntrybemgrp);
drop _cntrybemgrp;

qui do "$root/conc/secbem.do";
label values sec1_bem secbem;
compress;
order mneid cntrybemgrp;
sort mneid cntrybemgrp;

order mneid cntrybemgrp nreg s k t w l cf;
label var nreg "No. of active regions";
label var naff "No. of affiliates by region";
label var s "Cost share (theta)";
label var k "ln Fixed asset stock";
label var t "ln Turnover";
label var w "ln Wage rate";
label var l "ln Employment";
label var cf "Correction factor (tot C/reg w)";
label var nofdi "Indic.: No FDI";

tempfile cfreg;
preserve;
  keep mneid cntrybemgrp cf;
  foreach reg in HOM $regagg {;
    local r2dg = substr("`reg'",1,2);
    gen cf`r2dg' = cf if cntrybemgrp=="`reg'";
    };
  drop cntrybemgrp cf;
  collapse (sum) cf*, by(mneid);
  foreach reg in HOM $regagg {;
    local r2dg = substr("`reg'",1,2);
    label var cf`r2dg' "Correction factor `reg'";
    };
  sort mneid;
  save `cfreg';
restore;
drop cf;
sort mneid;
merge mneid using `cfreg';
qui count if _m~=3;
if `r(N)'>0  STOP;
drop _m;
sort mneid;

save "Xdata/mneid-outwfdi-ustan-`year'-translog-$waglvl-pt$par-af$aff", replace; 

#delimit cr; 

} /* end year loop */

log close
cd "$root"
