*! version 1.0.4  02aug2005  by Marc Muendler    muendler@ucsd.edu
*! version 1.0.6  13dec2005  by Karolina Ekholm  neke@hhs.se
*! version 1.0.7  15jan2006  by Marc Muendler    muendler@ucsd.edu

clear
set memory 500m
set more off
capture log close

cd "$rootslct"
log using "logs/prep-vars-others-pt$par-af$aff.log", replace

global varlist "employmt ln_dist ln_gdp ln_gdp_cap ln_consum_exp ln_cons_cap lh99_1 lh99_2 ln_mktacc"
if "$method"~=""  local methstr = "-$method"


/* Calculate Competitor's Country-level Variables (prior Logit regressors) */
/*-------------------------------------------------------------------------*/

foreach year in 1996 2000 {

/* Auxiliary data */

tempfile wdi iso3buba barrolee cntrylst mktacc cntrgrpbem

global year `year'
global wdi "`wdi'"
global cntrylst "`cntrylst'"
do $dpref/#wdi-external.do

use "$root/conc/fdi-iso-country", clear
rename buba country
keep iso3code country 
sort iso3code
compress
save `iso3buba'

use "$root/countries/barro-lee-99-pwt-iso", clear
replace iso3code="MMR" if iso3code=="BUR" /* Myanmar replaces Burma */
sort iso3code
merge iso3code using `iso3buba', nokeep
tab _merge
drop _merge countryname pwt61 pwt56
label var lh99  "High schl. attainm't p. tot pop"
label var lhc99 "High schl. complet'n p. tot pop"
label var tyr99 "Avg years schlng. in tot pop"
label var hyr99 "Avg y'rs high schlg. in tot pop"
sort country
compress
save `barrolee'

global year `year'
global mktacc "`mktacc'"
do $dpref/#prep-mktpot.do

use "$root/conc/cntry2bemgrp", clear
rename bubakey country
tab cntrygrp_bem
gen str3 cntrybemgrp = "CEE" if cntrygrp_bem=="CEE"
replace  cntrybemgrp = "DEV" if cntrygrp_bem=="APC" | cntrygrp_bem=="ODV" | cntrygrp_bem=="OTR" | cntrygrp_bem=="RCA"
replace  cntrybemgrp = "OIN" if cntrygrp_bem=="OIN"
replace  cntrybemgrp = "WEU" if cntrygrp_bem=="EMU" | cntrygrp_bem=="OWE"
label var cntrybemgrp "Country group BEM"
rename cntrybemgrp _cntrybemgrp
encode _cntrybemgrp, gen(cntrybemgrp) label(cntrybem)
drop _cntrybemgrp cntrygrp_bem
rename cntrybemgrp _cntrybemgrp
decode _cntrybemgrp, gen(cntrybemgrp)
drop _cntrybemgrp
sort country
compress
save `cntrgrpbem'

/* Main data */

use "Xdata/data-parent-hostcntry-pt$par-af$aff", clear
keep if year == `year'
keep firmid country year employmt sec1_bem
rename firmid mneid

sort country 
merge country using ${wdi}, nokeep 
tab _m
count if _m==1
if `r(N)'>0 {
  disp as err "Incomplete WDI country information in " in yellow `year'
  * STOP
  }
tab country if _merge==1, nolab 
drop _merge

sort country
merge country using `barrolee', nokeep
tab _merge
count if _m==1
if `r(N)'>0 {
  disp as err "Incomplete Barro-Lee information at country-level in " in yellow `year'
  * STOP
  }
tab country if _merge==1
drop _merge

sort country
merge country using `mktacc', nokeep
tab _merge
count if _m==1
if `r(N)'>0 {
  disp as err "Incomplete market potential information at country-level in " in yellow `year'
  tab country if _m==1
  * STOP
  }
tab country if _merge==1
drop _merge iso3code

sort country
merge country using `cntrgrpbem'
tab _merge
drop _merge
order mneid year country cntrybemgrp

keep mneid year country cntrybemgrp sec1_bem employmt population gdp_ppp gdp_cap_ppp consum_expend_ppp cons_cap_ppp ln_dist lh99 lhc99 tyr99 hyr99 mktacc
foreach var in gdp_ppp gdp_cap_ppp consum_expend_ppp cons_cap_ppp mktacc {
  qui gen ln_`var'=log(`var')
  local lbl : variable label `var'
  local lbl = upper(substr("`lbl'",1,1)) + lower(substr("`lbl'",2,length("`lbl'")-1))
  label var ln_`var' "ln `lbl'"
  drop `var'
  }
label var ln_dist         "ln Distance (capt'l-capt'l)"
label var ln_gdp_ppp      "ln GDP [EUR ppp]"
label var ln_gdp_cap_ppp  "ln GDP per cap. [EUR ppp]"
label var ln_consum_exp   "ln Cons. exp. [EUR ppp]"
label var ln_cons_cap_ppp "ln Cns.ex. p.cap [EUR ppp]"
label var ln_mktacc       "ln Market Access (MA(3))"
gen byte d_barro_lee_1=(${blcut}>lh99)
gen byte d_barro_lee_2=(${blcut}<lh99)
label var d_barro_lee_1 "lh99 for Hom > lh99 abroad"
label var d_barro_lee_2 "lh99 for Hom < lh99 abroad"
gen lh99_1=d_barro_lee_1*lh99
gen lh99_2=d_barro_lee_2*lh99
label var lh99_1 "lh99 if lh99 Hom > lh99"
label var lh99_2 "lh99 if lh99 Hom < lh99"
drop lh99 lhc99 tyr99 hyr99 d_barro* population

* firm-specific variables by region
local varlist "$varlist"
foreach var in ln_gdp ln_gdp_cap ln_consum_expend ln_cons_cap {
  rename `var'_ppp `var'
  }
rename ln_consum_expend ln_consum_exp
local i 0
foreach var in `varlist' {
  local i = `i' + 1
  local lbl`i' : variable label `var'
  }
bysort mneid year: egen double aggempl = sum(employmt)
label var aggempl "World-wide MNE employment"
collapse (sum) `varlist', by(mneid year cntrybemgrp aggempl sec1_bem) fast
local i 0
foreach var in `varlist' {
  local i = `i' + 1
  label var `var' "`lbl`i''"
  }

* reshape
foreach var in `varlist' {
  rename `var' `var'_othr_
  }
local vartot : word count `varlist'
tokenize `varlist'
local varlist ""
forvalues i = 1/`vartot' {
  local varlist "`varlist' ``i''_othr_"
  }
reshape wide `varlist', i(mneid year aggempl sec1_bem) j(cntrybemgrp) string
foreach reg in $regagg {
  local i 0
  foreach var in `varlist' {
    local i = `i' + 1
    label var `var'`reg' "`lbl`i'' `reg'"
    }
  local r2dg = substr("`reg'",1,2)
  label var lh99_1_othr_`reg' "lh99 `reg' (if lh99 HO > lh99 `r2dg')"
  label var lh99_2_othr_`reg' "lh99 `reg' (if lh99 HO < lh99 `r2dg')"
  }

* firm-by-firm averages over all other MNEs
count
local totnum = `r(N)'
gen _no = _n
order _n
compress
local i 0
preserve
forvalues i = 0/`totnum' {
  tempfile locvar`i'
  restore, preserve
  * mean employment-weighted location variables by region and sector
  local sec1bem = sec1_bem[`i']
  qui drop if _no == `i'
  if `sec1bem'~=. { 
    qui keep if sec1_bem == `sec1bem'
    }
  drop _no mneid year
  collapse (mean) * [pw=aggempl], fast
  drop aggempl
  gen _no = `i'
  order _no
  qui compress
  qui save `locvar`i''
  }
restore, preserve

tempfile locvars
qui use `locvar0', clear
forvalues i = 1/`totnum' {
  qui append using `locvar`i''
  }
sort _no
save `locvars'


/* Finalize */
/*----------*/

restore
keep _no mneid year
sort _no
merge _no using `locvars'
tab _m
count if _m==1
if `r(N)' {
  disp as err "Incomplete observations of competitors' location variables"
  STOP
  }
drop _m _no

foreach reg in $regagg {
  local i 0
  foreach var in `varlist' {
    local i = `i' + 1
    label var `var'`reg' "`lbl`i'' `reg'"
    }
  local r2dg = substr("`reg'",1,2)
  label var lh99_1_othr_`reg' "lh99 `reg' (if lh99 HO > lh99 `r2dg')"
  label var lh99_2_othr_`reg' "lh99 `reg' (if lh99 HO < lh99 `r2dg')"
  }

replace mneid=0 if mneid==.
duplicates drop /* Drops duplicate MNE 0 (mneid==0 is market average) */
drop year
sort mneid
order mneid
compress
save "Xdata/mneid-outwfdi-ustan-`year'-locvars-pt$par-af$aff", replace

* world-wide aggregates of variables
egen _tot_employmt_othr = rsum(employmt_othr_CEE employmt_othr_DEV employmt_othr_OIN employmt_othr_WEU)
foreach var in `varlist' {
  if "`var'"~="employmt_othr_" {
    local varname = substr("`var'",1,length("`var'")-1)
    foreach reg in $regagg {
      gen double _add_`var'`reg' = `var'`reg' * employmt_othr_`reg'
      }
    egen double `varname' = rsum(_add_`var'CEE _add_`var'DEV _add_`var'OIN _add_`var'WEU) 
    replace `varname' = `varname' / _tot_employmt_othr
    drop `varname'_* _add_`var'*
    }
  }
drop employmt_othr_*
rename _tot_employmt_othr employmt_othr

local i 0
foreach var in `varlist' {
  local i = `i' + 1
  local varname = substr("`var'",1,length("`var'")-1)
  label var `varname' "`lbl`i''"
  }
label var lh99_1_othr "Avg lh99 (if lh99 HO > lh99 FO)"
label var lh99_2_othr "Avg lh99 (if lh99 HO < lh99 FO)"

sort mneid
order mneid
compress
save "Xdata/mneid-outwfdi-ustan-`year'-wwlocvars-pt$par-af$aff", replace

}

log close
cd "$root"
