*! version 1.3.5  04nov2008  by Marc Muendler  muendler@ucsd.edu
*! version 2.1.1  14sep2009  by Marc Muendler  muendler@ucsd.edu

/* Varcov correction assumes that selection equations have constant */
/* Selection equation assumed to have constant as last regressor */
/* Varcov correction assumes that sureg equations do not have constant (add a regressor called ones if constant needed) */
/* Sure equation assumed to have Mills ratio as last regressor */
/* Regional wages are supposed to be first (5) regressors in SUR equations */

clear
set memory 400m
set matsize 800
set more off
capture log close

cd "$rootslct"

log using "logs/translog-selct-2stp-$waglvl-pt$par-af$aff-cf-nonparam-allyrs-ar2.log", replace

global poly 2  /* use second-order polynomials only; 1 2 3 possible */

*----------------------following code identical to translog-selct-2stp-cf-nonparam.do---------------------------------------------
*-----substitute: now for 00, ${yrdiff}yrlg for 96, /v6npfsar2 for /v6np, mneid year for mneid ---------------------------------------------------
*-----substitute: Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam-allyrs for Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam --

mat drop _all

local maxvars 4  /* longest used selection regressor varlist */
local surxno 15  /* number of SURE regressors per equation (excluding noFDI indicators, excluding adj. constant/ones and excluding propensity scores) */

local namelist "cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE cf_wresHO cf_wresCE cf_wresDE cf_wresOI cf_wresWE"
  foreach reg in $regagg {
    local r2dg = substr("`reg'",1,2)
    local namelist`r2dg' ""
    tokenize `namelist'
    local num :  word count `namelist'
    forvalues i = 1/`num' {
      local var = "cf`r2dg'_" + subinstr("``i''","cf_","",.)
      local namelist`r2dg' "`namelist`r2dg'' `var'"
      }
    }

adopath + "$root/%stata/ado"

#delimit ;


/* define X-equation restrictions */
/*--------------------------------*/

* constraint define  1 [sCE]cfCE_wHO = [sHO]cfHO_wCE;
  constraint define  2 [sCE]cfCE_wDE = [sDE]cfDE_wCE;
  constraint define  3 [sCE]cfCE_wOI = [sOI]cfOI_wCE;
  constraint define  4 [sCE]cfCE_wWE = [sWE]cfWE_wCE;
* constraint define  5 [sDE]cfDE_wHO = [sHO]cfHO_wDE;
  constraint define  6 [sDE]cfDE_wOI = [sOI]cfOI_wDE;
  constraint define  7 [sDE]cfDE_wWE = [sWE]cfWE_wDE;
* constraint define  8 [sOI]cfOI_wHO = [sHO]cfHO_wOI;
  constraint define  9 [sOI]cfOI_wWE = [sWE]cfWE_wOI;
* constraint define 10 [sWE]cfWE_wHO = [sHO]cfHO_wWE;
* constraint define 11 [sHO]cfHO_wHO + [sHO]cfHO_wCE + [sHO]cfHO_wDE + [sHO]cfHO_wOI + [sHO]cfHO_wWE = 0;
  constraint define 12 [sCE]cfCE_wHO + [sCE]cfCE_wCE + [sCE]cfCE_wDE + [sCE]cfCE_wOI + [sCE]cfCE_wWE = 0;
  constraint define 13 [sDE]cfDE_wHO + [sDE]cfDE_wCE + [sDE]cfDE_wDE + [sDE]cfDE_wOI + [sDE]cfDE_wWE = 0;
  constraint define 14 [sOI]cfOI_wHO + [sOI]cfOI_wCE + [sOI]cfOI_wDE + [sOI]cfOI_wOI + [sOI]cfOI_wWE = 0;
  constraint define 15 [sWE]cfWE_wHO + [sWE]cfWE_wCE + [sWE]cfWE_wDE + [sWE]cfWE_wOI + [sWE]cfWE_wWE = 0;

/* With 5 regions, there are (5*5-5)/2=10 symmetry restrictions in principle. 
   However, one equation drops due to further cross-equation constraints, 
   only 6 of the symmetry restrictions are needed.
   Similarly, only 4 of the 5 restrictions on wage parameter sums are needed. */


/* variable sets for selection estimation */
/*----------------------------------------*/

do $dp/!varsets-np.do;

*----------------------above code identical to translog-selct-2stp-cf-nonparam.do---------------------------------------------;

/* data */
/*------*/

foreach usemissg in $howmany {; /* begin `usemissg' loop */

*----------------------following code identical to translog-selct-2stp-cf-nonparam.do-----------------------------------------;

capture mkdir "$rootslct/tex/v6npfsar2";
capture mkdir "$rootslct/estmat/v6npfsar2";
capture mkdir "$rootslct/tex/v6npfsar2/pt$par-af$aff-$waglvl-cf";
capture mkdir "$rootslct/estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf";
capture mkdir "$rootslct/estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf/byreg";
capture mkdir "$rootslct/estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'";

*----------------------above code identical to translog-selct-2stp-cf-nonparam.do---------------------------------------------;


use "$rootslct/Xdata/mneid-regdata-d$yrdiff-$waglvl-pt$par-af$aff-cf", clear;
tsset, clear;
drop ln_inter_now;
rename ln_inter_${yrdiff} ln_inter;

foreach var in turnover employmt fixdasst equity liab caplabrat profits profeqtyrat intmed wb exports {;
  replace `var'_par_${yrdiff}yrlg=0 if `var'_par_${yrdiff}yrlg==.;
  };

if `usemissg' == 0 {;
  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    foreach var of varlist s`r2dg' w`r2dg' t`r2dg' k`r2dg' y`r2dg' cf??_w`r2dg' cf??_t`r2dg' cf??_k`r2dg' cf`r2dg' {;
      qui replace `var'=. if nofdi`r2dg'==1;
      };
    };
  };

*----------------------following code identical to translog-selct-2stp-cf-nonparam.do--------------------------------------------------;
*-----substitute: now for 00, ${yrdiff}yrlg for 96, /n3npfs for /v6npr, mneid year for mneid --------------------------------------------------;
*-----substitute: Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam-allyrs for Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam --;


/* nonparametric base variables for sureg estimation */
/*---------------------------------------------------*/

local dintact "ifdiCE ifdiDE ifdiWE ifdiOI";
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  local pscores`r2dg' "psc`r2dg' psc`r2dg'_`r2dg' psc`r2dg'_`r2dg'_`r2dg'";
  tokenize `pscores`r2dg'';
  local num : word count `pscores`r2dg'';
  local remtrm "ifdi`r2dg'";
  local multact : list dintact - remtrm;
  foreach dummy in `multact' {;
    forvalues i = 1/`num' {;
      local addtrm "``i''*`dummy'";
      local pscores`r2dg' "`pscores`r2dg'' `addtrm'";
      };
    };
  };
* disp "`pscoresCE'"; * disp "`pscoresDE'"; * disp "`pscoresOI'"; * disp "`pscoresWE'";
local pscno : word count `pscoresCE';
disp "`pscno'";


*----------------------above code identical to translog-selct-2stp-cf-nonparam.do---------------------------------------------;

* note: data section removed;

*----------------------following code identical to translog-selct-2stp-cf-nonparam.do-----------------------------------------;

* matrices for marginal effects of wages on selection and of propensity scores on labor demand;
mat pscdlnw = J(4,5,.);
mat suredps = J(4,4,0);
matrix rownames pscdlnw = $regagg;
matrix rownames suredps = $regagg;
matrix colnames pscdlnw = HOM $regagg;
matrix colnames suredps = $regagg;
local rownames : rowfullnames pscdlnw;
local rownum : word count `rownames';
tokenize `rownames';
forvalues rowi = 1/`rownum' {;
  local rownew = "i_" + substr("``rowi''",-3,3);
  matname pscdlnw `rownew', rows(`rowi') explicit;
  local rownew = "y_" + substr("``rowi''",-3,3);
  matname suredps `rownew', rows(`rowi') explicit;
  };
local colnames : colfullnames pscdlnw;
local colnum : word count `colnames';
tokenize `colnames';
forvalues coli = 1/`colnum' {;
  local colnew = "w_" + substr("``coli''",-3,3);
  matname pscdlnw `colnew', columns(`coli') explicit;
  };
local colnames : colfullnames suredps;
local colnum : word count `colnames';
tokenize `colnames';
forvalues coli = 1/`colnum' {;
  local colnew = "ps_" + substr("``coli''",-3,3);
  matname suredps `colnew', columns(`coli') explicit;
  };

* Create selection polynomial regressors;
tokenize $selser;
local selno : word count $selser;
forvalues i = 1/`selno' {;
  local varname "``i''";
  local preptrm = subinstr(subinstr("``i''","w_","",.),"_"," ",.);
  * first-order terms;
  local var1 :  word 1 of `preptrm';
  if lower("`var1'")~="`var1'"  local var1 "w_othr_`var1'";
  else  local var1 "ln_`var1'";
  if substr("`var1'",-3,3)=="HOM"  local var1 = subinstr("`var1'","_othr","",.);
  * second-order terms;
  local var2 :  word 2 of `preptrm';
  if lower("`var2'")~="`var2'" & length("`var2'")>0  local var2 "w_othr_`var2'";
  if lower("`var2'")=="`var2'" & length("`var2'")>0  local var2 "ln_`var2'";
  if length("`var2'")>0  local var2 " * `var2'";
  if substr("`var2'",-3,3)=="HOM"  local var2 = subinstr("`var2'","_othr","",.);
  * third-order terms;
  local var3 :  word 3 of `preptrm';
  if lower("`var3'")~="`var3'" & length("`var3'")>0  local var3 "w_othr_`var3'";
  if lower("`var3'")=="`var3'" & length("`var3'")>0  local var3 "ln_`var3'";
  if length("`var3'")>0  local var3 " * `var3'";
  if substr("`var3'",-3,3)=="HOM"  local var3 = subinstr("`var3'","_othr","",.);
  if length("`var2'")>0 {;
    qui gen double `varname' = `var1'`var2'`var3';
    label var `varname' "(`varname')";
    };
  };
  * sector dummies;
  qui summ sec1_bem;
  local minsec = `r(min)'+1;
  local maxsec = `r(max)';
  local dumlst = "_Isec1_bem_`minsec'";
  local secdum = "_b[_Isec1_bem_`minsec']*_Isec1_bem_`minsec'";
  local secavgdum = "_b[_Isec1_bem_`minsec']*_MN_Isec1_bem_`minsec'";
  local minsec = `minsec' + 1;
  forvalues j = `minsec'/`maxsec' {;
    local dumlst "`dumlst' _Isec1_bem_`j'";
    local secdum "`secdum' + _b[_Isec1_bem_`j']*_Isec1_bem_`j'";
    local secavgdum "`secavgdum' + _b[_Isec1_bem_`j']*_MN_Isec1_bem_`j'";
    };
      
*----------------------above code identical to translog-selct-2stp-cf-nonparam.do-------------------------------------------;

*----------------------following code specific to crossval-selct-2stp-cf-nonparam-allyrs-ar2.do-----------------------------------------;

/* identify polynomial interaction terms */
/*---------------------------------------*/

local selser1 = subinstr(subinstr("${par_1}","_othr","",.),"ln_","",.);
local selser2 ""; /* second-order terms */
local cnt 0;
foreach var of local selser1 {;
  local cnt = `cnt' + 1;
  tokenize `selser1';
  local selno : word count `selser1';
  forvalues i = `cnt'/`selno' {;
    local addtrm = subinstr("`var'_``i''","_w_","_",.);
    local selser2 "`selser2' `addtrm'";
    };
  };
local selser3 ""; /* third-order terms */
local cnt 0;
foreach var of local selser1 {;
  tokenize `selser2';
  local selno : word count `selser2';
  forvalues i = 1/`selno' {;
    if index("`selser1'",substr("`var'",-3,3)) >= index("`selser1'",substr("``i''",-3,3)) {;
      local addtrm = subinstr("``i''_`var'","_w_","_",.);
      local selser3 "`selser3' `addtrm'";
      };
    };
  };


/* first step: non-parametric selection estimation */
/*-------------------------------------------------*/

foreach reg in $regagg {;
  forvalues xvars = ${usexvar}/${usexvar} {;  /* `maxvars'(-1)0 */
    local r2dg = substr("`reg'",1,2);
    tempname chk;
    if `xvars'==0  local interact "";
    else           local interact "i`r2dg'${yrdiff}yrlg_wHO";

    * polynomial terms;
    local polytrms ${parnp_`xvars'};
    if ${poly}<=2  local polytrms : list polytrms - selser3;
    if ${poly}==1  local polytrms : list polytrms - selser2;
    
    * selection regressions with sector dummies;
    xi: capture noi xtgee i`r2dg'now iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `interact' `polytrms' i.sec1, family(gaussian) i(mneid) t(year) corr(ar 2) iterate(250);
    capture local chk = rowsof(selreg`r2dg'_b);
    if _rc==111 {;
      est2vec selreg`r2dg', vars(iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg i`r2dg'${yrdiff}yrlg_wHO ${parnp_`maxvars'} _Isec1_bem_1 _Isec1_bem_2 _Isec1_bem_3 _Isec1_bem_4 _Isec1_bem_5 _Isec1_bem_6 _Isec1_bem_7 _Isec1_bem_8 _Isec1_bem_9 _cons) e(N ll F chi2 df_m r2 r2_p) name(`r2dg'`xvars'i);
      * est2vec selreg`r2dg', r(entry_chi2 entry_df entry_p exit_chi2 exit_df exit_p hyst_chi2 hyst_df hyst_p locvar_F locvar_df locvar_p mnevar_F mnevar_df mnevar_p) name(`r2dg'`xvars'i);
      };
    else {;
      est2vec selreg`r2dg', addto(selreg`r2dg') name(`r2dg'`xvars'i);
      * est2vec selreg`r2dg', raddto(selreg`r2dg') name(`r2dg'`xvars'i);
      };
    * tests for joint significance by region;
    tokenize `polytrms';
    local regrno : word count `polytrms';
    foreach tstreg in HOM $regagg {;
      local t2dg = substr("`tstreg'",1,2);
      local tstlst`t2dg' = "";
      forvalues i = 1/`regrno' {;
        if subinstr("``i''","`tstreg'","",.)~="``i''" & substr("``i''",1,2)=="w_"  local tstlst`t2dg' "`tstlst`t2dg'' ``i''";
        };
      * disp in yellow "`tstlst`t2dg''";
      if "`tstlst`t2dg''"~=""  capture  test `tstlst`t2dg'';
      if "`tstlst`t2dg''"~="" & _rc==0  est2vec r`t2dg', r(F df p) name(`r2dg'`xvars'i);
      else {;
        mat r`t2dg'_r = J(3,1,.);
        matrix rownames r`t2dg'_r = F df p;
        };
    };
    capture mat selreg`r2dg'_r = selreg`r2dg'_r , ( J(15,1,.) \ rHO_r \ rCE_r \ rDE_r \ rOI_r \ rWE_r );
    if _rc {;
      mat selreg`r2dg'_r = ( J(15,1,.) \ rHO_r \ rCE_r \ rDE_r \ rOI_r \ rWE_r );
      };
    local matcol = colsof(selreg`r2dg'_r);
    matname selreg`r2dg'_r `r2dg'`xvars'i, columns(`matcol') explicit;
    mat drop rHO_r rCE_r rDE_r rOI_r rWE_r;

    * selection regressions without sector dummies (used for translog);
    * disp "parnp_`xvars': `polytrms'";
    capture noi xtgee i`r2dg'now iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `interact' `polytrms', family(gaussian) i(mneid) t(year) corr(ar 2) iterate(250);
    capture local chk = rowsof(selreg`r2dg'_b);
    if _rc==111 {;
      est2vec selreg`r2dg', vars(iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg i`r2dg'${yrdiff}yrlg_wHO ${parnp_`maxvars'} _Isec1_bem_1 _Isec1_bem_2 _Isec1_bem_3 _Isec1_bem_4 _Isec1_bem_5 _Isec1_bem_6 _Isec1_bem_7 _Isec1_bem_8 _Isec1_bem_9 _cons) e(N ll F chi2 df_m r2 r2_p) name(`r2dg'`xvars');
      * est2vec selreg`r2dg', r(entry_chi2 entry_df entry_p exit_chi2 exit_df exit_p hyst_chi2 hyst_df hyst_p locvar_F locvar_df locvar_p mnevar_F mnevar_df mnevar_p) name(`r2dg'`xvars');
      };
    else {;
      est2vec selreg`r2dg', addto(selreg`r2dg') name(`r2dg'`xvars');
      * est2vec selreg`r2dg', raddto(selreg`r2dg') name(`r2dg'`xvars');
      };
    * tests for hysteresis and identification;
    test - _cons = 0; 
    est2vec r1, r(F df p) name(`r2dg'`xvars');
    test i`r2dg'${yrdiff}yrlg + _cons = 0; 
    est2vec r2, r(F df p) name(`r2dg'`xvars');
    test - i`r2dg'${yrdiff}yrlg = 0; 
    est2vec r3, r(F df p) name(`r2dg'`xvars');
    capture test ln_mktacc_othr lh99_1_othr lh99_2_othr ln_dist_othr ln_cons_cap_othr;
    est2vec r4, r(F df p) name(`r2dg'`xvars');
    capture test ln_inter_${yrdiff}yrlg ${addlmne} employmt_par_${yrdiff}yrlg fixdasst_par_${yrdiff}yrlg turnover_par_${yrdiff}yrlg intmed_par_${yrdiff}yrlg liab_par_${yrdiff}yrlg;
    est2vec r5, r(F df p) name(`r2dg'`xvars');
    * tests for joint significance by region;
    tokenize `polytrms';
    local regrno : word count `polytrms';
    foreach tstreg in HOM $regagg {;
      local t2dg = substr("`tstreg'",1,2);
      local tstlst`t2dg' = "";
      forvalues i = 1/`regrno' {;
        if subinstr("``i''","`tstreg'","",.)~="``i''" & substr("``i''",1,2)=="w_"  local tstlst`t2dg' "`tstlst`t2dg'' ``i''";
        };
      * disp in yellow "`tstlst`t2dg''";
      if "`tstlst`t2dg''"~=""  test `tstlst`t2dg'';
      if "`tstlst`t2dg''"~=""  est2vec r`t2dg', r(F df p) name(`r2dg'`xvars');
      else {;
        mat r`t2dg'_r = J(3,1,.);
        matrix rownames r`t2dg'_r = F df p;
        };
    };
    capture mat selreg`r2dg'_r = selreg`r2dg'_r , ( r1_r \ r2_r \ r3_r \ r4_r \ r5_r \ rHO_r \ rCE_r \ rDE_r \ rOI_r \ rWE_r );
    if _rc {;
      mat selreg`r2dg'_r = ( r1_r \ r2_r \ r3_r \ r4_r \ r5_r \ rHO_r \ rCE_r \ rDE_r \ rOI_r \ rWE_r );
      };
    matrix rownames selreg`r2dg'_r = entry_F entry_df entry_p exit_F exit_df exit_p hyst_F hyst_df hyst_p locvar_F locvar_df locvar_p mnevar_F mnevar_df mnevar_p wHOM_F wHOM_df wHOM_p wCEE_F wCEE_df wCEE_p wDEV_F wDEV_df wDEV_p wOIN_F wOIN_df wOIN_p wWEU_F wWEU_df wWEU_p;
    mat drop r1_r r2_r r3_r r4_r r5_r;
    mat drop rHO_r rCE_r rDE_r rOI_r rWE_r;

    * predict propensity scores from selection regressions without sector dummies;
    if `xvars' == ${usexvar} {;   /* Only xvars ${usexvar} used for second stage */
      predict double psc`r2dg', xb;
      label var psc`r2dg' "Propensity score `r2dg' (xvars `xvars')";
      * summ psc`r2dg';

    * predict log wage residual;
    foreach reg2 in HOM $regagg {;
      local r2dg2 = substr("`reg2'",1,2);
      reg lnw_`r2dg2' iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `interact' `polytrms';
      est2vec selreg`r2dg', addto(selreg`r2dg') name(resw`r2dg2'eq`r2dg'`xvars');
      predict double cf`r2dg'_wres`r2dg2', res;
      replace cf`r2dg'_wres`r2dg2' = cf`r2dg' * cf`r2dg'_wres`r2dg2';
      replace cf`r2dg'_wres`r2dg2' = 0 if cf`r2dg'_wres`r2dg2'==.;
      };
    };

    * observation-specific predictions for extensive margins, selection part;
    if `xvars' == ${usexvar} {;   /* only xvars ${usexvar} used for second stage */
      tokenize `polytrms' iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `dumlst';
      local regrno : word count `polytrms' iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `dumlst';
      forvalues i = 1/`regrno' {;
        local varname = subinstr("_MN``i''","othr_","",.);
        qui egen double `varname' = mean(``i'') if e(sample);
        };
      * operate on: w_HOM w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU w_HOM_2 w_othr_CEE_2 w_othr_DEV_2 w_othr_OIN_2 w_othr_WEU_2;
      *        and  w_HOM_CEE w_HOM_DEV w_HOM_OIN w_HOM_WEU w_HOM_inter w_HOM_mktacc w_CEE_DEV w_CEE_OIN w_CEE_WEU w_CEE_inter w_CEE_mktacc w_DEV_OIN w_DEV_WEU w_DEV_inter w_DEV_mktacc w_OIN_WEU w_OIN_inter w_OIN_mktacc;
      *        etc.;

      * Evaluation of wage effects;
      tokenize `polytrms';
      local regrno : word count `polytrms';
      foreach wreg in HOM $regagg {;
        local predacc "_b[_cons]";  /* predicted poynomial terms, varying only by `wreg' wage (all other vars are sample means) */
        * local restavgacc "`secavgdum' + _b[iCE${yrdiff}yrlg]*_MNiCE${yrdiff}yrlg + _b[iDE${yrdiff}yrlg]*_MNiDE${yrdiff}yrlg + _b[iOI${yrdiff}yrlg]*_MNiOI${yrdiff}yrlg + _b[iWE${yrdiff}yrlg]*_MNiWE${yrdiff}yrlg";  /* predicted remaining terms, not varying (sample means) */
        local restavgacc "_b[iCE${yrdiff}yrlg]*_MNiCE${yrdiff}yrlg + _b[iDE${yrdiff}yrlg]*_MNiDE${yrdiff}yrlg + _b[iOI${yrdiff}yrlg]*_MNiOI${yrdiff}yrlg + _b[iWE${yrdiff}yrlg]*_MNiWE${yrdiff}yrlg";  /* predicted remaining terms, not varying (sample means) */
        * local restacc "`secdum' + _b[iCE${yrdiff}yrlg]*iCE${yrdiff}yrlg + _b[iDE${yrdiff}yrlg]*iDE${yrdiff}yrlg + _b[iOI${yrdiff}yrlg]*iOI${yrdiff}yrlg + _b[iWE${yrdiff}yrlg]*iWE${yrdiff}yrlg";  /* predicted remaining terms, varying by all variables for standard error calculation */
        local restacc "_b[iCE${yrdiff}yrlg]*iCE${yrdiff}yrlg + _b[iDE${yrdiff}yrlg]*iDE${yrdiff}yrlg + _b[iOI${yrdiff}yrlg]*iOI${yrdiff}yrlg + _b[iWE${yrdiff}yrlg]*iWE${yrdiff}yrlg";  /* predicted remaining terms, varying by all variables for standard error calculation */
        local matacc "0";  /* marginal effect of `wreg' wage */
        * local chkacc "`predacc' + `restacc'";  /* for consistency checks (disabled) */
        local w2dg = substr("`wreg'",1,2);
        local regvar = "w_othr_`wreg'";
        if "`wreg'"=="HOM"  local regvar = "w_`wreg'";
        forvalues i = 1/`regrno' {;
          if length(subinstr("``i''","`wreg'","",.)) < length("``i''") {;  /* wage variable appears in token: treat */
            if lower(subinstr("``i''","`wreg'","",.)) == subinstr("``i''","`wreg'","",.) & substr(subinstr("``i''","`wreg'","",.),-1,1)=="_" {;  /* only `wreg' terms appear in token */
              local predacc "`predacc' + _b[``i'']*``i''";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-3  {; 
                if substr("`wreg'",-3,3)=="HOM" local matacc "`matacc' + _b[``i''] + _b[i`r2dg'${yrdiff}yrlg_w`w2dg']*_MNi`r2dg'${yrdiff}yrlg";
                else                            local matacc "`matacc' + _b[``i''] + _b[i`w2dg'${yrdiff}yrlg_w`w2dg']*_MNi`w2dg'${yrdiff}yrlg";
                };
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-6  local matacc "`matacc' + 2*_b[``i'']*`regvar'";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-9  local matacc "`matacc' + 3*_b[``i'']*w_`wreg'_`wreg'";
              * local chkacc "`chkacc' + _b[``i'']*``i''";
              };
            else {; /* mixed `wreg' and other terms appear in token */
              local covar = "_MN" + subinstr(subinstr(subinstr(subinstr("``i''","`wreg'","",.),"__","_",.),"__","_",.),"othr_","",.);
              if substr("`covar'",-1,1)=="_"  local covar = substr("`covar'",1,length("`covar'")-1);
              if lower(subinstr("`covar'","_MN","",.))==subinstr("`covar'","_MN","",.) & length("`covar'")<=12  local covar = subinstr("`covar'","w_","ln_",.);
              if lower(subinstr("`covar'","_MN","",.))==subinstr("`covar'","_MN","",.) & length("`covar'") >12  local covar = subinstr("`covar'","w_","",.);
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-3  local predacc "`predacc' + _b[``i'']*`regvar'*`covar'";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-6  local predacc "`predacc' + _b[``i'']*w_`wreg'_`wreg'*`covar'";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-3  local matacc "`matacc' + _b[``i'']*`covar'";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-6  local matacc "`matacc' + 2*_b[``i'']*`regvar'*`covar'";
              * local chkacc "`chkacc' + _b[``i'']*``i''";
              };
            };
          if length(subinstr("``i''","`wreg'","",.)) == length("``i''") {;  /* wage variable does not appear in token: store for mean subtraction */
            local exclvar = subinstr("``i''","othr_","",.);
            local restavgacc "`restavgacc' + _b[``i'']*_MN`exclvar'";
            local restacc "`restacc' + _b[``i'']*``i''";
            * local chkacc "`chkacc' + _b[``i'']*``i''";
            };
          };
        * disp in yellow "`predacc'"; * disp in yellow "`restacc'"; * disp in yellow "`restavgacc'"; * disp in yellow "`matacc'";
        qui gen double dpsc`r2dg'dw`w2dg' = `predacc' + `restavgacc' if e(sample);
        * qui gen double __chkacc = `chkacc' if e(sample);
        * summ __chkacc psc`r2dg';  /* check identity */
        * drop __chkacc;
        qui gen double _mpsc`r2dg'w`w2dg' = `matacc' if e(sample);
        qui summ _mpsc`r2dg'w`w2dg', meanonly;
        mat pscdlnw[rownumb(pscdlnw,"i_`reg'"),colnumb(pscdlnw,"w_`wreg'")] = `r(mean)';
        * CIs from SE of prediction (default);
        * qui gen double dpsc`r2dg'dw`w2dg'_se = i`r2dg'now - dpsc`r2dg'dw`w2dg' + `restavgacc' - `restacc' if e(sample); /* split gen double command to shorten line */
        qui gen double dpsc`r2dg'dw`w2dg'_se = i`r2dg'now - dpsc`r2dg'dw`w2dg' if e(sample);
        qui replace dpsc`r2dg'dw`w2dg'_se = dpsc`r2dg'dw`w2dg'_se + `restavgacc' if e(sample); 
        qui replace dpsc`r2dg'dw`w2dg'_se = dpsc`r2dg'dw`w2dg'_se - `restacc' if e(sample);
        qui gen double dpsc`r2dg'dw`w2dg'_lcl = dpsc`r2dg'dw`w2dg' - invttail(e(df_r),((100-${S_level})/200)) * dpsc`r2dg'dw`w2dg'_se if e(sample);
        qui gen double dpsc`r2dg'dw`w2dg'_ucl = dpsc`r2dg'dw`w2dg' + invttail(e(df_r),((100-${S_level})/200)) * dpsc`r2dg'dw`w2dg'_se if e(sample);
        label var dpsc`r2dg'dw`w2dg' "Wage w`w2dg' effect on selection i`r2dg'";
        label var dpsc`r2dg'dw`w2dg'_lcl "${S_level}% CI w`w2dg' eff on sel i`r2dg'";
        label var dpsc`r2dg'dw`w2dg'_ucl "${S_level}% CI w`w2dg' eff on sel i`r2dg'";
        * sort `regvar';
        * twoway connected dpsc`r2dg'dw`w2dg' dpsc`r2dg'dw`w2dg'_lcl dpsc`r2dg'dw`w2dg'_ucl `regvar';
        * twoway connected dpsc`r2dg'dw`w2dg' `regvar';
        drop dpsc`r2dg'dw`w2dg'_se;
        * drop _mpsc`r2dg'w`w2dg'; 
        }; /* close wreg loop */
      drop _MN*;
      };

    };  /* close xvars loop */
  };  /* close reg loop */

sort mneid year;
disp in gr "Matrix of wage effects on FDI presence (usemissg: " in ye `usemissg' in gr ")";
mat list pscdlnw;

* Save data for bootstrap routine;
preserve;
  drop _* dpsc`r2dg'dw`w2dg'*;
  drop cf??_wres??;
  sort mneid year;
  save "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam-allyrs", replace;
restore;

* Generate polynomial interaction terms for sureg regression;
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  qui gen byte ifdi`r2dg' = 1 - nofdi`r2dg';
  qui gen double psc`r2dg'_`r2dg' = psc`r2dg'*psc`r2dg';
  qui gen double psc`r2dg'_`r2dg'_`r2dg' = psc`r2dg'_`r2dg'*psc`r2dg';
  };
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  local pscser`r2dg';
  foreach var of local pscores`r2dg' {;
    local namvar = subinstr("`var'","*","_",.);
    capture qui gen double `namvar' = `var';
    local pscser`r2dg' "`pscser`r2dg'' `namvar'";
    };
  };
* disp "`pscserCE'"; * disp "`pscserDE'"; * disp "`pscserOI'"; * disp "`pscserWE'";
local pscno : word count `pscserCE';
disp "`pscno'";


/* second step: seemingly unrelated regressions with nonparametric error terms */
/*-----------------------------------------------------------------------------*/

if `usemissg' == 0 {;
sureg (sCE: yCE = `namelistCE' cfCE `pscserCE')
      (sDE: yDE = `namelistDE' cfDE `pscserDE')
      (sOI: yOI = `namelistOI' cfOI `pscserOI')
      (sWE: yWE = `namelistWE' cfWE `pscserWE')
      , constraints(2 3 4 6 7 9 12 13 14 15) corr isur iterate($maxiter);
*     (sHO: yHO = `namelistHO' cfHO `pscserHO'); /* left-out equation */
};

if `usemissg' == 1 {;
sureg (sCE: yCE = `namelistCE' nofdiDE nofdiOI nofdiWE cfCE `pscserCE')
      (sDE: yDE = `namelistDE' nofdiCE nofdiOI nofdiWE cfDE `pscserDE')
      (sOI: yOI = `namelistOI' nofdiCE nofdiDE nofdiWE cfOI `pscserOI')
      (sWE: yWE = `namelistWE' nofdiCE nofdiDE nofdiOI cfWE `pscserWE')
      , constraints(2 3 4 6 7 9 12 13 14 15) corr isur iterate($maxiter);
*     (sHO: yHO = `namelistHO' nofdiCE nofdiDE nofdiOI nofdiWE cfHO `pscserHO'); /* left-out equation */
};

est2vec translog`usemissg', e(N rss k_eq levels chi2_bp df_bp r2_1 chi2_1 p_1 r2_2 chi2_2 p_2 r2_3 chi2_3 p_3 r2_4 chi2_4 p_4) name(translog_`usemissg');

* tests for joint significance of higher-order terms;
mat translog`usemissg'_r = J(12,1,.);
local colname : colfullnames translog`usemissg'_b;
matrix rownames translog`usemissg'_r = r(chi2_CE) r(df_CE) r(p_CE) r(chi2_DE) r(df_DE) r(p_DE) r(chi2_OI) r(df_OI) r(p_OI) r(chi2_WE) r(df_WE) r(p_WE);
matrix colnames translog`usemissg'_r = `colname';
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  local testm`r2dg' "[s`r2dg']_b[cf`r2dg']";
  tokenize `pscser`r2dg'';
  local num : word count `pscser`r2dg'';
  forvalues i = 1/`num' {;
    local testm`r2dg' "`testm`r2dg'' [s`r2dg']_b[``i'']";
    };
  test `testm`r2dg'';
  foreach rstat in chi2 df p {;
    mat translog`usemissg'_r[rownumb(translog`usemissg'_r,"r(`rstat'_`r2dg')"),1] = r(`rstat');
    };
  };

if `usemissg' == 0 {;
  order mneid year sHO kHO tHO wHO cfHO sCE kCE tCE wCE cfCE sDE kDE tDE wDE cfDE sOI kOI tOI wOI cfOI sWE kWE tWE wWE cfWE;
  };
if `usemissg' == 1 {;
  order mneid year sHO kHO tHO wHO nofdiHO cfHO sCE kCE tCE wCE nofdiCE cfCE sDE kDE tDE wDE nofdiDE cfDE sOI kOI tOI wOI nofdiOI cfOI sWE kWE tWE wWE nofdiWE cfWE;
  };

* observation-specific predictions for extensive margins, sureg part;
*   operate on: `pscserCE' `pscserDE' `pscserOI' `pscserWE';
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  egen double _MNifdi`r2dg' = mean(ifdi`r2dg') if e(sample);
  };
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  * Evaluation of selection effects;
    local pspredacc "_b[s`r2dg':_cons]"; 
    local psrestacc "0";
    local psrestavgacc "0";
    local pspredacc "`pspredacc' + _b[s`r2dg':psc`r2dg']*psc`r2dg' + _b[s`r2dg':psc`r2dg'_`r2dg']*psc`r2dg'_`r2dg' + _b[s`r2dg':psc`r2dg'_`r2dg'_`r2dg']*psc`r2dg'_`r2dg'_`r2dg'";
    local psmatacc "_b[s`r2dg':psc`r2dg'] + 2*_b[s`r2dg':psc`r2dg'_`r2dg']*psc`r2dg' + 3*_b[s`r2dg':psc`r2dg'_`r2dg'_`r2dg']*psc`r2dg'_`r2dg'";
    local restreg : list global(regagg) - local(reg);
    foreach wreg in `restreg' {;
      local w2dg = substr("`wreg'",1,2);
      local addpred "_b[s`r2dg':psc`r2dg'_ifdi`w2dg']*psc`r2dg'*_MNifdi`w2dg' + _b[s`r2dg':psc`r2dg'_`r2dg'_ifdi`w2dg']*psc`r2dg'_`r2dg'*_MNifdi`w2dg' + _b[s`r2dg':psc`r2dg'_`r2dg'_`r2dg'_ifdi`w2dg']*psc`r2dg'_`r2dg'_`r2dg'*_MNifdi`w2dg'";
      local addmat  "_b[s`r2dg':psc`r2dg'_ifdi`w2dg']*_MNifdi`w2dg' + 2*_b[s`r2dg':psc`r2dg'_`r2dg'*_MNifdi`w2dg']*psc`r2dg'*_MNifdi`w2dg' + 3*_b[s`r2dg':psc`r2dg'_`r2dg'_`r2dg'_ifdi`w2dg']*psc`r2dg'_`r2dg'*_MNifdi`w2dg'";
      local pspredacc "`pspredacc' + `addpred'";
      local psmatacc "`psmatacc' + `addpred'";
      }; /* close wreg loop */
    * disp in yellow "`pspredacc'"; * disp in yellow "`psrestacc'"; * disp in yellow "`psrestavgacc'";
    qui gen double dy`r2dg'dps`r2dg' = `pspredacc' + `psrestavgacc' if e(sample);
    qui gen double _mdy`r2dg'psc`r2dg' = `psmatacc' if e(sample);
    qui summ _mdy`r2dg'psc`r2dg', meanonly;
    mat suredps[rownumb(suredps,"y_`reg'"),colnumb(suredps,"ps_`reg'")] = `r(mean)';
    * CIs from SE of prediction (default);
    qui gen double dy`r2dg'dps`r2dg'_se = y`r2dg' - dy`r2dg'dps`r2dg' + `psrestavgacc' - `psrestacc' if e(sample);
    qui gen double dy`r2dg'dps`r2dg'_lcl = dy`r2dg'dps`r2dg' - invttail(e(df_m1),((100-${S_level})/200)) * dy`r2dg'dps`r2dg'_se if e(sample);
    qui gen double dy`r2dg'dps`r2dg'_ucl = dy`r2dg'dps`r2dg' + invttail(e(df_m1),((100-${S_level})/200)) * dy`r2dg'dps`r2dg'_se if e(sample);
    label var dy`r2dg'dps`r2dg' "Selection i`r2dg' effect on labor demand y`r2dg'";
    label var dy`r2dg'dps`r2dg'_lcl "${S_level}% CI i`r2dg' eff on empl y`r2dg'";
    label var dy`r2dg'dps`r2dg'_ucl "${S_level}% CI i`r2dg' eff on empl y`r2dg'";
    * sort psc`r2dg';
    * twoway connected dy`r2dg'dps`r2dg' dy`r2dg'dps`r2dg'_lcl dy`r2dg'dps`r2dg'_ucl psc`r2dg' if psc`r2dg'>=0 & psc`r2dg'<=1;
    * twoway connected dy`r2dg'dps`r2dg' psc`r2dg' if psc`r2dg'>=0 & psc`r2dg'<=1;
    drop dy`r2dg'dps`r2dg'_se;
    * drop _mdy`r2dg'psc`r2dg';    
  }; /* close reg loop */
drop _MN*;

sort mneid year;
disp in gr "Matrix of selection effects on labor demand (usemissg: " in ye `usemissg' in gr ")";
mat list suredps;


/* initial concavity checks */
/*--------------------------*/

* matrix to check (i) that the fitted cost shares sLOC_predicted are nonnegative;
mat negxhatcnt`usemissg' = J(2,4,.);
matname negxhatcnt`usemissg' r(N_neg_xhare) r(N), rows(1..2) explicit;
local i = 0;
foreach sreg in sCE sDE sOI sWE {;
  local i = `i' + 1;
  matname negxhatcnt`usemissg' `sreg', columns(`i') explicit;
  predict _`sreg' if e(sample), equation(`sreg') xb;
  qui count if _`sreg'<0 & e(sample);
  mat negxhatcnt`usemissg'[1,`i']=`r(N)';
  qui count if e(sample);
  mat negxhatcnt`usemissg'[2,`i']=`r(N)';
  };
drop _s*;


/* sample statistics for elasticities of substitution */
/*----------------------------------------------------*/

order mneid year nreg sec1_bem i* _I*;
summ2tex * if e(sample), c(mean sd N p50) name(summ_translog`usemissg') p(tex/v6npfsar2/pt$par-af$aff-$waglvl-cf) replace detail;
preserve;
  foreach var in sHO sCE sDE sOI sWE wHO wCE wDE wOI wWE tHO tCE tDE tOI tWE kHO kCE kDE kOI kWE cfHO cfCE cfDE cfOI cfWE {;
    replace `var' = . if `var'==0;
    };
  summ2tex * if e(sample), c(mean sd N p50) name(summ_translog`usemissg'_missg) p(tex/v6npfsar2/pt$par-af$aff-$waglvl-cf) replace detail;
  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    summ2tex * if e(sample) & nofdi`r2dg'==0, c(mean sd N p50) name(summ_translog`usemissg'_missg`r2dg') p(tex/v6npfsar2/pt$par-af$aff-$waglvl-cf) replace detail;
    };
restore;
corr2tex sHO sCE sDE sOI sWE if e(sample), name(corrT_translog`usemissg') p(tex/v6npfsar2/pt$par-af$aff-$waglvl-cf) replace;


/* elasticities of substitution */
/*------------------------------*/

* Cross-wage coefficient matrix;
tempname VCE; /* resets prior `VCE' if defined */
tempname bcoef bse coefmat0 semat0 coefmat1 semat1 coefmat2 semat2 coefmat3 semat3 coefmat4 semat4; 
mat `bcoef' = e(b)';
mat `VCE' = e(V);  /* Heckman corrected if positive semi-definite under re-run */
mat `bse' = vecdiag(`VCE')';
* mat `bse' = vecdiag(`VCEkeep')'; /* Permit checking for symmetry in absence of Heckman correction */
foreach mattyp in coef se {;
  mat ``mattyp'mat0' = J(5,1,.);
  local cnt 0;
  foreach reg in $regagg {;
    local cnt = `cnt' + 1;
    local r2dg = substr("`reg'",1,2);
    if `usemissg'~=2  matorder `b`mattyp'', m(``mattyp'mat`cnt'') ifr(s`r2dg':cf`r2dg'_wHO s`r2dg':cf`r2dg'_wCE s`r2dg':cf`r2dg'_wDE s`r2dg':cf`r2dg'_wOI s`r2dg':cf`r2dg'_wWE);
    local col`cnt' : roweq ``mattyp'mat`cnt''; local col`cnt' = substr("`col`cnt''",1,3);
    };
  * mat list ``mattyp'mat1';
  * mat list ``mattyp'mat2';
  * mat list ``mattyp'mat3';
  * mat list ``mattyp'mat4';
  mat `mattyp'mat = ``mattyp'mat0' , ``mattyp'mat1' , ``mattyp'mat2' , ``mattyp'mat3' , ``mattyp'mat4';
  * mat list `mattyp'mat;
  mat ``mattyp'mat0' = `mattyp'mat[1,1..5] ';
  mat `mattyp'mat = ``mattyp'mat0' , ``mattyp'mat1' , ``mattyp'mat2' , ``mattyp'mat3' , ``mattyp'mat4';
  mat `mattyp'mat[1,1] = - (`mattyp'mat[2,1] + `mattyp'mat[3,1] + `mattyp'mat[4,1] + `mattyp'mat[5,1]);
  local collbl = subinstr("wHO `col1' `col2' `col3' `col4'","s","w",.);
  local rowlbl = "sHO `col1' `col2' `col3' `col4'";
  * disp "`collbl'";
  * disp "`rowlbl'";
  matname `mattyp'mat `collbl', columns(1..5) explicit;
  matname `mattyp'mat `rowlbl', rows(1..5) explicit;
};
* standard error for sHOwHO;
local sdHOHO = 0;
forvalues i = 2/5 {;
  forvalues j = 2/5 {;
    local sdHOHO = `sdHOHO' + semat[`i',`j'];
    };
  };
mat semat[1,1] = sqrt(`sdHOHO');
mat list coefmat; mat list semat;

* Observation-specific extensive margins;
tempname suredlnw;
mat `suredlnw' = suredps * pscdlnw;
foreach weff in HOM $regagg {;
  local w2dg = substr("`weff'",1,2);
  gen double xmrHOw`w2dg' = 0;
  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    local regvar = "w_othr_`weff'";
    if "`weff'"=="HOM"  local regvar = "w_`weff'";
    local dpsc`r2dg'dw`w2dg' = `suredlnw'[rownumb(`suredlnw',"y_`reg'"),colnumb(`suredlnw',"w_`weff'")];
    * qui gen double xmr`r2dg'w`w2dg' = (_mdy`r2dg'pscCE*_mpscCEw`w2dg' + _mdy`r2dg'pscDE*_mpscDEw`w2dg' + _mdy`r2dg'pscOI*_mpscOIw`w2dg' + _mdy`r2dg'pscWE*_mpscWEw`w2dg') * i`r2dg'now / cf`r2dg' ; /* if log wages used; observations */
    * qui gen double xmr`r2dg'w`w2dg' = (_mdy`r2dg'pscCE*_mpscCEw`w2dg' + _mdy`r2dg'pscDE*_mpscDEw`w2dg' + _mdy`r2dg'pscOI*_mpscOIw`w2dg' + _mdy`r2dg'pscWE*_mpscWEw`w2dg') * i`r2dg'now * `regvar' / cf`r2dg' ; /* if plain wages used; observations */
    * qui gen double xmr`r2dg'w`w2dg' = `dpsc`r2dg'dw`w2dg'' * i`r2dg'now / cf`r2dg' ; /* if log wages used; mean matrix */
    qui gen double xmr`r2dg'w`w2dg' = `dpsc`r2dg'dw`w2dg'' * i`r2dg'now * `regvar' / cf`r2dg' ; /* if plain wages used; mean matrix */
    replace xmr`r2dg'w`w2dg'=. if abs(xmr`r2dg'w`w2dg')>1;  /* disregard implausible outliers */
    };
  };

* Save predictions by observation for twoway plots;
preserve;
  keep mneid year dpsc??dw?? dpsc??dw??_lcl dpsc??dw??_ucl dy??dps?? dy??dps??_lcl dy??dps??_ucl xmr??w?? w_* psc??;
  sort mneid year;
  if `usemissg'==1  save "$rootslct/Xdata/mneid-fortwoway-$waglvl-pt$par-af$aff-cf-nonparam-allyrs", replace;
restore;

* Matrix of mean extensive margin correction terms;
capture mat drop xmrmat;
local rownames : rowfullnames coefmat;  /* Match regional pattern in coefmat at intensive margin */
local colnames : colfullnames coefmat;
local colnum : word count `colnames';
foreach reg in `rownames' {;
  local r2dg = substr("`reg'",-2,2);
  tempname xmat`r2dg';
  mat `xmat`r2dg'' = J(1,`colnum',.);
  matname `xmat`r2dg'' s`r2dg', rows(1) explicit;
  local colj = 0;
  foreach weff in `colnames' {;
    local colj = `colj' + 1;
    qui summ xmr`r2dg'`weff' if s`r2dg'~=0 & e(sample), meanonly;  /* only calculate mean over sample MNEs with presence */
    mat `xmat`r2dg''[1,`colj'] = r(mean);
    matname `xmat`r2dg'' `weff', columns(`colj') explicit;
    };
  capture mat xmrmat = xmrmat \ `xmat`r2dg'';
  if _rc {;
    mat xmrmat = `xmat`r2dg'';
    };
  };
foreach reg in `rownames' {;
  local r2dg = substr("`reg'",-2,2);
  disp; 
  disp "Coefficient on own-region propensity score in `r2dg': `pstrlg`r2dg''";
  disp "Extensive margin correction terms for `r2dg'";
  summ xmr`r2dg'w* if s`r2dg'~=0 & e(sample);
  };
mat list xmrmat;

* Statistics for matrices of shares (predicted shares recommended by Berndt 1991 and Hayashi 2000 but not used);
local eqs = subinstr("`rownames'","sHO","",.);
foreach reg in `eqs' {;
  local r2dg = substr("`reg'",-2,2);
  * qui predict double shat`r2dg', equation(s`r2dg') xb, if e(sample);
  gen double shat`r2dg' = s`r2dg';
  };
gen double shatHO = sHO;
preserve;
collapse (mean) shatHO shatCE shatDE shatOI shatWE if e(sample), fast;
mkmat shatHO shatCE shatDE shatOI shatWE, matrix(Tmat);  /* Tmat to be transposed to a column vector below */
matname Tmat theta, rows(1) explicit;
restore, preserve;
collapse (sd) shatHO shatCE shatDE shatOI shatWE if e(sample), fast;
mkmat shatHO shatCE shatDE shatOI shatWE, matrix(Tmat_sd);
matname Tmat_sd theta_sd, rows(1) explicit;
restore, preserve;
collapse (count) shatHO shatCE shatDE shatOI shatWE if e(sample), fast;
mkmat shatHO shatCE shatDE shatOI shatWE, matrix(Tmat_N);
matname Tmat_N theta_N, rows(1) explicit;
restore, preserve;

* Zeta matrix (r2 in Anderson and Thursby 1986);
foreach sreg in HOM $regagg {;
  local sr2dg = substr("`sreg'",1,2);
  foreach wreg in HOM $regagg {;
    local wr2dg = substr("`wreg'",1,2);
    qui gen double r2s`sr2dg's`wr2dg' = Tmat_N[1,colnumb(Tmat_N,"s`sr2dg'")]^(-3) * ( ( s`sr2dg' - Tmat[1,colnumb(Tmat,"s`sr2dg'")] ) * ( s`sr2dg'*s`wr2dg' - Tmat[1,colnumb(Tmat,"s`sr2dg'")]*Tmat[1,colnumb(Tmat,"s`wr2dg'")] - corrT_translog`usemissg'_tbl[rownumb(corrT_translog`usemissg'_tbl,"s`sr2dg'"),colnumb(corrT_translog`usemissg'_tbl,"s`wr2dg'")]*Tmat_sd[1,colnumb(Tmat_sd,"s`sr2dg'")]*Tmat_sd[1,colnumb(Tmat_sd,"s`wr2dg'")] ) + Tmat_N[1,colnumb(Tmat_N,"s`sr2dg'")]*(Tmat_N[1,colnumb(Tmat_N,"s`sr2dg'")] - 1)*Tmat[1,colnumb(Tmat,"s`sr2dg'")]*Tmat_sd[1,colnumb(Tmat_sd,"s`sr2dg'")]*( Tmat_sd[1,colnumb(Tmat_sd,"s`sr2dg'")] + corrT_translog`usemissg'_tbl[rownumb(corrT_translog`usemissg'_tbl,"s`sr2dg'"),colnumb(corrT_translog`usemissg'_tbl,"s`wr2dg'")]*Tmat_sd[1,colnumb(Tmat_sd,"s`wr2dg'")] ) );
    };
  };
collapse (sum) r2sHOsHO r2sHOsCE r2sHOsDE r2sHOsOI r2sHOsWE r2sCEsHO r2sCEsCE r2sCEsDE r2sCEsOI r2sCEsWE r2sDEsHO r2sDEsCE r2sDEsDE r2sDEsOI r2sDEsWE r2sOIsHO r2sOIsCE r2sOIsDE r2sOIsOI r2sOIsWE r2sWEsHO r2sWEsCE r2sWEsDE r2sWEsOI r2sWEsWE if e(sample), fast;
tempname zetatmp;
mkmat r2sHOsHO r2sHOsCE r2sHOsDE r2sHOsOI r2sHOsWE r2sCEsHO r2sCEsCE r2sCEsDE r2sCEsOI r2sCEsWE r2sDEsHO r2sDEsCE r2sDEsDE r2sDEsOI r2sDEsWE r2sOIsHO r2sOIsCE r2sOIsDE r2sOIsOI r2sOIsWE r2sWEsHO r2sWEsCE r2sWEsDE r2sWEsOI r2sWEsWE, matrix(`zetatmp');
local shnames : colfullnames Tmat;
local shnames = subinstr("`shnames'","hat","",.);
mat zetamat = J(5,5,.);
matname zetamat `shnames', rows(1..5) explicit;
matname zetamat `shnames', columns(1..5) explicit;
foreach sr in `shnames' {;
  local sr2dg = subinstr("`sr'","s","",.);
  foreach wr in `shnames' {;
    local wr2dg = subinstr("`wr'","s","",.);
    mat zetamat[rownumb(zetamat,"`sr'"),colnumb(zetamat,"`wr'")] = `zetatmp'[1,colnumb(`zetatmp',"r2s`sr2dg's`wr2dg'")];
    };
  };
restore;

* Matrices of shares;
mat Tmat_all = Tmat \ Tmat_sd \ Tmat_N;
mat Tmat = Tmat'; /* Tmat transposed to a column vector */
mat Tsqmat = Tmat * Tmat';

* Calculate total cross-price elasticities (both margins);
mat TotElast = coefmat + xmrmat + Tsqmat;
forvalues r = 2/5 {; /* Fill lower-echelon entries */
local maxcol = `r'-1;
  forvalues m = 1/`maxcol' {;
    mat TotElast[`r',`m'] = TotElast[`r',`m'] / Tmat[`r',1];
    };
  };
forvalues m = 2/5 {; /* Fill upper-echelon entries */
local maxrow = `m'-1;
  forvalues r = 1/`maxrow' {;
    mat TotElast[`r',`m'] = TotElast[`r',`m'] / Tmat[`r',1];
    };
  };
forvalues r = 1/5 {;  /* Fill diagonal entries */
    mat TotElast[`r',`r'] = TotElast[`r',`r'] / Tmat[`r',1] - 1;
  };
matname TotElast `shnames', rows(1..5) explicit;
matname TotElast `shnames', columns(1..5) explicit;
mat list TotElast;
disp;

* Calculate cross-price elasticities matrix at extensive margin;
mat ExtElast = xmrmat + Tsqmat;
forvalues r = 2/5 {; /* Fill lower-echelon entries */
local maxcol = `r'-1;
  forvalues m = 1/`maxcol' {;
    mat ExtElast[`r',`m'] = ExtElast[`r',`m'] / Tmat[`r',1];
    };
  };
forvalues m = 2/5 {; /* Fill upper-echelon entries */
local maxrow = `m'-1;
  forvalues r = 1/`maxrow' {;
    mat ExtElast[`r',`m'] = ExtElast[`r',`m'] / Tmat[`r',1];
    };
  };
forvalues r = 1/5 {;  /* Fill diagonal entries and cancel HOM row */
    mat ExtElast[`r',`r'] = ExtElast[`r',`r'] / Tmat[`r',1] - 1;
    mat ExtElast[1,`r'] = 0;
  };
matname ExtElast `shnames', rows(1..5) explicit;
matname ExtElast `shnames', columns(1..5) explicit;
mat list ExtElast;
disp;

* Calculate cross-price elasticities matrix at intensive margin;
mat IntElast = coefmat + Tsqmat;
forvalues r = 2/5 {; /* Fill lower-echelon entries */
local maxcol = `r'-1;
  forvalues m = 1/`maxcol' {;
    mat IntElast[`r',`m'] = IntElast[`r',`m'] / Tmat[`r',1];
    };
  };
forvalues m = 2/5 {; /* Fill upper-echelon entries */
local maxrow = `m'-1;
  forvalues r = 1/`maxrow' {;
    mat IntElast[`r',`m'] = IntElast[`r',`m'] / Tmat[`r',1];
    };
  };
forvalues r = 1/5 {;  /* Fill diagonal entries */
    mat IntElast[`r',`r'] = IntElast[`r',`r'] / Tmat[`r',1] - 1;
  };
matname IntElast `shnames', rows(1..5) explicit;
matname IntElast `shnames', columns(1..5) explicit;
mat list IntElast;
disp;


/* additional concavity checks */
/*-----------------------------*/

* matrix to check (ii) that the cross price elasticities in TotElast sum to zero per row (not per column);
mat elastsum`usemissg' = J(2,5,0);
matname elastsum`usemissg' rowsum colsum, rows(1..2) explicit;
matname elastsum`usemissg' sHO sCE sDE sOI sWE, columns(1..5) explicit;
local i = 0;
foreach sreg in sHO sCE sDE sOI sWE {;
  local i = `i' + 1;
  forvalues j = 1/5 {;
    mat elastsum`usemissg'[1,`i'] = elastsum`usemissg'[1,`i'] + TotElast[`i',`j'];
    mat elastsum`usemissg'[2,`i'] = elastsum`usemissg'[2,`i'] + TotElast[`j',`i'];
    };
  };

* matrix to check (iii) that the AUmat matrices of Allen-Uzawa substitution elasticities are negative semi-definite at each observation;
* calculate MNE-level elasticities (in-sample predictions); 
* set elasticities to zero for regions with no FDI-presence;
local i = 0;
foreach reg1 in HO CE DE OI WE {;
  local i = `i' + 1;
  local j = 0;
  foreach reg2 in HO CE DE OI WE {;
    local j = `j' + 1;
    local coeff = coefmat[`i',`j'];
    if `i' ~= `j' {; 
      qui gen double sigma`reg1's`reg2' = (`coeff' + s`reg1' * s`reg2') / (s`reg1' * s`reg2') if e(sample);
      };
    if `i' == `j' {; 
      qui gen double sigma`reg1's`reg1' = (`coeff' + (s`reg1')^2 - s`reg1') / (s`reg1')^2 if e(sample);
      };      
    qui replace sigma`reg1's`reg2'=0 if sigma`reg1's`reg2'==.;
    label var sigma`reg1's`reg2' "AU elast. empl`reg1' empl`reg2'";
    };
  };
qui count;
local obsnum = `r(N)';
tempname AUmatobs eigenvec eigenval;
mat negeivalcnt`usemissg' = J(1,5,0) \ J(1,5,`obsnum');
matname negeivalcnt`usemissg' r(N_wklyneg_eigval) r(N), rows(1..2) explicit;
matname negeivalcnt`usemissg' wklyneg_1 wklyneg_2 wklyneg_3 wklyneg_4 wklyneg_5, columns(1..5) explicit;
forvalues obs = 1/`obsnum'{;
  mat `AUmatobs' = J(5,5,.);
  local i = 0;
  foreach reg1 in HO CE DE OI WE {;
    local i = `i' + 1;
    local j = 0;
    foreach reg2 in HO CE DE OI WE {;
      local j = `j' + 1;
      mat `AUmatobs'[`i',`j'] = sigma`reg1's`reg2'[`obs'];
      };
    };
  matrix symeigen `eigenvec' `eigenval' = `AUmatobs';
  matname `eigenval' `eigenval'ue, rows(1) explicit;
  mat drop `eigenvec';
  local cntwklyneg = 0;
  forvalues k = 1/5 {;
    if `eigenval'[1,`k'] <= 1.0e-06 {;  /* machine-size weakly negative */
      local cntwklyneg = `cntwklyneg' + 1;
      };
    };
  mat negeivalcnt`usemissg'[1,`cntwklyneg'] = negeivalcnt`usemissg'[1,`cntwklyneg']+1;
  };


/* matrix output */
/*---------------*/

foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  foreach type in b se e {;
    drop _all;
    matsave selreg`r2dg'_`type', p(estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf/byreg) t(double) replace;
    };
  drop _all;
  matsave selreg`r2dg'_r, p(estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf/byreg) t(double) replace;
  };

foreach type in b se e r {;
    drop _all;
    matsave translog`usemissg'_`type', p(estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg') t(double) replace;
    };
matsave negxhatcnt`usemissg', p(estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace; 
matsave elastsum`usemissg', p(estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace; 
matsave negeivalcnt`usemissg', p(estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace; 

mat intelast`usemissg'_b = IntElast;
matsave intelast`usemissg'_b, p(estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;
mat extelast`usemissg'_b = ExtElast;
matsave extelast`usemissg'_b, p(estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;
mat totelast`usemissg'_b = TotElast;
matsave totelast`usemissg'_b, p(estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;

mat vce`usemissg'_tbl = `VCE';
local cols = colsof(vce`usemissg'_tbl);
matsave vce`usemissg'_tbl, p(estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;

mat tmat`usemissg'_tbl = Tmat_all;
matsave tmat`usemissg'_tbl, p(estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;
mat zetamat`usemissg'_tbl = zetamat;
matsave zetamat`usemissg'_tbl, p(estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;

mat coefmat`usemissg'_tbl = coefmat;
matname coefmat`usemissg'_tbl wHO wCE wDE wOI wWE, columns(1..5) explicit;
matname coefmat`usemissg'_tbl sHO sCE sDE sOI sWE, rows(1..5) explicit;
matsave coefmat`usemissg'_tbl, p(estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;

mat semat`usemissg'_tbl = semat;
matname semat`usemissg'_tbl wHO wCE wDE wOI wWE, columns(1..5) explicit;
matname semat`usemissg'_tbl sHO sCE sDE sOI sWE, rows(1..5) explicit;
matsave semat`usemissg'_tbl, p(estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;

mat xmrmat`usemissg'_tbl = xmrmat;
matname xmrmat`usemissg'_tbl wHO wCE wDE wOI wWE, columns(1..5) explicit;
matname xmrmat`usemissg'_tbl sHO sCE sDE sOI sWE, rows(1..5) explicit;
matsave xmrmat`usemissg'_tbl, p(estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg') dropall t(double) replace;

* clean up;
drop _all;
mat drop coefmat semat xmrmat zetamat Tmat Tmat_sd Tmat_N Tmat_all Tsqmat TotElast ExtElast IntElast;
foreach mat in summ_translog`usemissg' summ_translog`usemissg'_missg corrT_translog`usemissg' vce`usemissg' coefmat`usemissg' semat`usemissg' tmat`usemissg' xmrmat`usemissg' zetamat`usemissg' {;
  mat drop `mat'_tbl;
  };
foreach type in b se e r {;
  capture mat drop translog`usemissg'_`type';
  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    capture mat drop selreg`r2dg'_`type';
    capture mat drop selreg`r2dg'_`type';
    capture mat drop sure2stp`r2dg'_`type';
    };
  };
mat drop negxhatcnt`usemissg' elastsum`usemissg' negeivalcnt`usemissg';
mat drop totelast`usemissg'_b;
mat drop intelast`usemissg'_b;
mat drop extelast`usemissg'_b;
mat drop pscdlnw suredps;

}; /* end of `usemissg' loop */

*----------------------above code specific to translog-selct-2stp-cf-nonparam-allyrs-ar2.do-------------------------------------------;

log close;
cd "$root";
